-- +OORRGIISS
-- -OORRGCCCC
ezCollections.CameraOptions =
{
    "Classic",
    "HD2017",
    "HD2019",
};
ezCollections.CameraOptionsToCameraID = { };
for id, name in ipairs(ezCollections.CameraOptions) do
    ezCollections.CameraOptionsToCameraID[name] = id * 10000000;
end
ezCollections.RaceToCameraID =
{
    Human                  =  1 *   100000,
    Orc                    =  2 *   100000,
    Dwarf                  =  3 *   100000,
    NightElf               =  4 *   100000,
    Scourge                =  5 *   100000,
    Tauren                 =  6 *   100000,
    Gnome                  =  7 *   100000,
    Troll                  =  8 *   100000,
    Goblin                 =  9 *   100000,
    BloodElf               = 10 *   100000,
    Draenei                = 11 *   100000,
};
ezCollections.SexToCameraID =
{
    [1]                    =  1 *    10000,
    [2]                    =  1 *    10000,
    [3]                    =  2 *    10000,
};
ezCollections.InvTypeToCameraID =
{
    INVTYPE_NON_EQUIP      =  0 *      100,
    INVTYPE_HEAD           =  1 *      100,
    INVTYPE_NECK           =  2 *      100,
    INVTYPE_SHOULDER       =  3 *      100,
    INVTYPE_BODY           =  4 *      100,
    INVTYPE_CHEST          =  5 *      100,
    INVTYPE_WAIST          =  6 *      100,
    INVTYPE_LEGS           =  7 *      100,
    INVTYPE_FEET           =  8 *      100,
    INVTYPE_WRIST          =  9 *      100,
    INVTYPE_HAND           = 10 *      100,
    INVTYPE_FINGER         = 11 *      100,
    INVTYPE_TRINKET        = 12 *      100,
    INVTYPE_WEAPON         = 13 *      100,
    INVTYPE_SHIELD         = 14 *      100,
    INVTYPE_RANGED         = 15 *      100,
    INVTYPE_CLOAK          = 16 *      100,
    INVTYPE_2HWEAPON       = 17 *      100,
    INVTYPE_BAG            = 18 *      100,
    INVTYPE_TABARD         = 19 *      100,
    INVTYPE_ROBE           = 20 *      100,
    INVTYPE_WEAPONMAINHAND = 21 *      100,
    INVTYPE_WEAPONOFFHAND  = 22 *      100,
    INVTYPE_HOLDABLE       = 23 *      100,
    INVTYPE_AMMO           = 24 *      100,
    INVTYPE_THROWN         = 25 *      100,
    INVTYPE_RANGEDRIGHT    = 26 *      100,
    INVTYPE_QUIVER         = 27 *      100,
    INVTYPE_RELIC          = 28 *      100,

    SetsDetails            = 50 *      100,
    SetsVendor             = 51 *      100,
    DressUp                = 52 *      100,
};
ezCollections.SubClassToCameraID =       1;

function ezCollections:GetCharacterCameraID(invTypeName, cameraID)
    local fallback = self.CameraOptionsToCameraID[ezCollections.CameraOptions[1]];
    local option = self.CameraOptionsToCameraID[ezCollections.Config.Wardrobe.CameraOption];
    local race = self.RaceToCameraID[select(2, UnitRace("player"))];
    local sex = self.SexToCameraID[UnitSex("player")];
    if cameraID then
        local fullCameraID = option + race + sex + cameraID;
        local fallbackCameraID = fallback + race + sex + cameraID;
        if ezCollections.Cache.Cameras[fullCameraID] then
            return -fullCameraID;
        elseif ezCollections.Cache.Cameras[fallbackCameraID] then
            return -fallbackCameraID;
        end
    end

    local invType = self.InvTypeToCameraID[invTypeName];
    local fullCameraID = option + race + sex + invType;
    local fallbackCameraID = fallback + race + sex + invType;
    if self.Cameras[fullCameraID] then
        return fullCameraID;
    else
        return fallbackCameraID;
    end
end

function ezCollections:GetWeaponCameraID(invTypeName, subType, cameraID)
    if cameraID then
        if ezCollections.Cache.Cameras[cameraID] then
            return -cameraID;
        end
    end

    local invType = self.InvTypeToCameraID[invTypeName];
    local subType = self.SubClassToCameraID * ((subType or 0) + 1);
    if self.Cameras[invType + subType] then
        return invType + subType;
    else
        return invType;
    end
end

local cameraOptionAffectedInvTypes;
function ezCollections:PlayerHasDifferentCameraOptions()
    local race = self.RaceToCameraID[select(2, UnitRace("player"))];
    local sex = self.SexToCameraID[UnitSex("player")];
    local fallbackOption;
    for _, name in ipairs(ezCollections.CameraOptions) do
        local option = self.CameraOptionsToCameraID[name];
        if not fallbackOption then
            fallbackOption = option;
        else
            for _, invType in ipairs(cameraOptionAffectedInvTypes) do
                local fallback = ezCollections.Cameras[fallbackOption + race + sex + invType];
                local camera = ezCollections.Cameras[option + race + sex + invType];
                if fallback and camera then
                    local fx, fy, fz, ff, fa = unpack(fallback);
                    local ox, oy, oz, of, oa = unpack(camera);
                    if fx ~= ox or fy ~= oy or fz ~= oz or ff ~= of or fa ~= oa then
                        return true, option, fallbackOption, invType;
                    end
                end
            end
        end
    end
end

-- Populate ezCollections.Cameras
local O = ezCollections.CameraOptionsToCameraID;
local R = ezCollections.RaceToCameraID;
local I = ezCollections.InvTypeToCameraID;
local S = { Male = ezCollections.SexToCameraID[2], Female = ezCollections.SexToCameraID[3] }
local BACK = PI;
local MHAND = PI / 2;
local OHAND = 0;
local function Wpn(invType, subType)
    return invType + (subType and (subType + 1) or 0) * ezCollections.SubClassToCameraID;
end
local function Chr(option, race, sex, invType)
    return option + race + sex + invType;
end

cameraOptionAffectedInvTypes =
{
    I.INVTYPE_HEAD,
    I.INVTYPE_SHOULDER,
    I.INVTYPE_CLOAK,
    I.INVTYPE_CHEST,
    I.INVTYPE_ROBE,
    I.INVTYPE_BODY,
    I.INVTYPE_TABARD,
    I.INVTYPE_WRIST,
    I.INVTYPE_HAND,
    I.INVTYPE_WAIST,
    I.INVTYPE_LEGS,
    I.INVTYPE_FEET,
    I.SetsDetails,
    I.SetsVendor,
};

-- 2.5, -0.6, -0.9, 2.85, 124
ezCollections.Cameras =
{
    [Wpn(I.INVTYPE_WEAPON                                       )] = {  2.00, -0.52, -1.00, MHAND },
    [Wpn(I.INVTYPE_WEAPON,         LE_ITEM_WEAPON_SWORD1H       )] = {  2.00, -0.52, -1.10, MHAND },
    [Wpn(I.INVTYPE_WEAPON,         LE_ITEM_WEAPON_FIST          )] = {  2.25, -0.52, -0.75, MHAND },
    [Wpn(I.INVTYPE_WEAPONMAINHAND                               )] = {  2.00, -0.52, -1.00, MHAND },
    [Wpn(I.INVTYPE_WEAPONMAINHAND, LE_ITEM_WEAPON_SWORD1H       )] = {  2.00, -0.52, -1.10, MHAND },
    [Wpn(I.INVTYPE_WEAPONMAINHAND, LE_ITEM_WEAPON_FIST          )] = {  2.25, -0.52, -0.75, MHAND },
    [Wpn(I.INVTYPE_RANGEDRIGHT                                  )] = {  2.00, -0.52, -1.00, MHAND },
    [Wpn(I.INVTYPE_RANGEDRIGHT,    LE_ITEM_WEAPON_CROSSBOW      )] = {  2.00,  0.05, -1.00,  BACK },
    [Wpn(I.INVTYPE_RANGEDRIGHT,    LE_ITEM_WEAPON_WAND          )] = {  2.50, -0.52, -0.90, MHAND },
    [Wpn(I.INVTYPE_THROWN                                       )] = {  2.75, -0.52, -0.85, MHAND },
    [Wpn(I.INVTYPE_2HWEAPON                                     )] = {  1.50, -0.52, -1.00, MHAND },
    [Wpn(I.INVTYPE_2HWEAPON,       LE_ITEM_WEAPON_FISHINGPOLE   )] = {  1.00, -0.52, -1.25, MHAND },
    [Wpn(I.INVTYPE_WEAPONOFFHAND                                )] = {  1.35,  0.00, -0.75, OHAND },
    [Wpn(I.INVTYPE_WEAPONOFFHAND,  LE_ITEM_WEAPON_DAGGER        )] = {  1.40,  0.00, -0.70, OHAND },
    [Wpn(I.INVTYPE_WEAPONOFFHAND,  LE_ITEM_WEAPON_SWORD1H       )] = {  1.35,  0.00, -0.83, OHAND },
    [Wpn(I.INVTYPE_WEAPONOFFHAND,  LE_ITEM_WEAPON_FIST          )] = {  1.70,  0.00, -0.45, OHAND },
    [Wpn(I.INVTYPE_SHIELD                                       )] = {  2.00,  0.10, -0.30, -0.50, 110 },
    [Wpn(I.INVTYPE_HOLDABLE                                     )] = {  1.75,  0.00, -0.60, OHAND },
    [Wpn(I.INVTYPE_RANGED                                       )] = {  0.50, -0.05, -0.47, OHAND },
    -- Classic
    [Chr(O.Classic,     R.Human,    S.Male,   I.INVTYPE_HEAD    )] = {  2.25,  0.05, -0.75, -0.50 },
    [Chr(O.Classic,     R.Human,    S.Male,   I.INVTYPE_SHOULDER)] = {  2.00, -0.25, -0.65, -0.25 },
    [Chr(O.Classic,     R.Human,    S.Male,   I.INVTYPE_CLOAK   )] = {  1.30,  0.02,  0.00,  BACK },
    [Chr(O.Classic,     R.Human,    S.Male,   I.INVTYPE_CHEST   )] = {  1.90,  0.00, -0.45, -0.25 },
    [Chr(O.Classic,     R.Human,    S.Male,   I.INVTYPE_ROBE    )] = {  1.10,  0.00,  0.05, -0.25 },
    [Chr(O.Classic,     R.Human,    S.Male,   I.INVTYPE_BODY    )] = {  1.90,  0.00, -0.45, -0.25 },
    [Chr(O.Classic,     R.Human,    S.Male,   I.INVTYPE_TABARD  )] = {  1.50,  0.00, -0.15, -0.25 },
    [Chr(O.Classic,     R.Human,    S.Male,   I.INVTYPE_WRIST   )] = {  2.45, -0.25, -0.15, -0.50 },
    [Chr(O.Classic,     R.Human,    S.Male,   I.INVTYPE_HAND    )] = {  2.20, -0.25, -0.10, -0.50 },
    [Chr(O.Classic,     R.Human,    S.Male,   I.INVTYPE_WAIST   )] = {  2.20,  0.02, -0.20, -0.25 },
    [Chr(O.Classic,     R.Human,    S.Male,   I.INVTYPE_LEGS    )] = {  1.60,  0.00,  0.25, -0.25 },
    [Chr(O.Classic,     R.Human,    S.Male,   I.INVTYPE_FEET    )] = {  2.00,  0.05,  0.52, -0.80 },
    [Chr(O.Classic,     R.Human,    S.Male,   I.SetsDetails     )] = {  0.00,  0.02, -0.33,  0.00 },
    [Chr(O.Classic,     R.Human,    S.Male,   I.SetsVendor      )] = {  0.75,  0.02, -0.25,  0.00 },
    [Chr(O.Classic,     R.Human,    S.Female, I.INVTYPE_HEAD    )] = {  1.90,  0.02, -0.70, -0.50 },
    [Chr(O.Classic,     R.Human,    S.Female, I.INVTYPE_SHOULDER)] = {  1.90, -0.15, -0.60, -0.25 },
    [Chr(O.Classic,     R.Human,    S.Female, I.INVTYPE_CLOAK   )] = {  1.05,  0.01, -0.10,  BACK },
    [Chr(O.Classic,     R.Human,    S.Female, I.INVTYPE_CHEST   )] = {  1.85,  0.00, -0.40, -0.25 },
    [Chr(O.Classic,     R.Human,    S.Female, I.INVTYPE_ROBE    )] = {  0.90,  0.00,  0.05, -0.25 },
    [Chr(O.Classic,     R.Human,    S.Female, I.INVTYPE_BODY    )] = {  1.85,  0.00, -0.40, -0.25 },
    [Chr(O.Classic,     R.Human,    S.Female, I.INVTYPE_TABARD  )] = {  1.45,  0.00, -0.15, -0.25 },
    [Chr(O.Classic,     R.Human,    S.Female, I.INVTYPE_WRIST   )] = {  2.00, -0.16, -0.20, -0.50 },
    [Chr(O.Classic,     R.Human,    S.Female, I.INVTYPE_HAND    )] = {  1.90, -0.16, -0.15, -0.50 },
    [Chr(O.Classic,     R.Human,    S.Female, I.INVTYPE_WAIST   )] = {  1.90,  0.02, -0.20, -0.25 },
    [Chr(O.Classic,     R.Human,    S.Female, I.INVTYPE_LEGS    )] = {  1.25,  0.00,  0.22, -0.25 },
    [Chr(O.Classic,     R.Human,    S.Female, I.INVTYPE_FEET    )] = {  1.70,  0.03,  0.50, -0.35 },
    [Chr(O.Classic,     R.Human,    S.Female, I.SetsDetails     )] = {  0.00,  0.02, -0.33,  0.00 },
    [Chr(O.Classic,     R.Human,    S.Female, I.SetsVendor      )] = {  0.75,  0.02, -0.25,  0.00 },
    [Chr(O.Classic,     R.Orc,      S.Male,   I.INVTYPE_HEAD    )] = {  2.35,  0.10, -0.85, -0.50 },
    [Chr(O.Classic,     R.Orc,      S.Male,   I.INVTYPE_SHOULDER)] = {  2.10, -0.45, -0.80, -0.25 },
    [Chr(O.Classic,     R.Orc,      S.Male,   I.INVTYPE_CLOAK   )] = {  1.15,  0.02, -0.05,  BACK },
    [Chr(O.Classic,     R.Orc,      S.Male,   I.INVTYPE_CHEST   )] = {  1.75,  0.00, -0.50, -0.25 },
    [Chr(O.Classic,     R.Orc,      S.Male,   I.INVTYPE_ROBE    )] = {  1.20,  0.00,  0.00, -0.25 },
    [Chr(O.Classic,     R.Orc,      S.Male,   I.INVTYPE_BODY    )] = {  1.75,  0.00, -0.50, -0.25 },
    [Chr(O.Classic,     R.Orc,      S.Male,   I.INVTYPE_TABARD  )] = {  1.80,  0.00, -0.20, -0.25 },
    [Chr(O.Classic,     R.Orc,      S.Male,   I.INVTYPE_WRIST   )] = {  2.70, -0.40, -0.15, -0.50 },
    [Chr(O.Classic,     R.Orc,      S.Male,   I.INVTYPE_HAND    )] = {  2.40, -0.40, -0.05, -0.50 },
    [Chr(O.Classic,     R.Orc,      S.Male,   I.INVTYPE_WAIST   )] = {  2.40,  0.00, -0.25, -0.25 },
    [Chr(O.Classic,     R.Orc,      S.Male,   I.INVTYPE_LEGS    )] = {  1.75,  0.00,  0.25, -0.25 },
    [Chr(O.Classic,     R.Orc,      S.Male,   I.INVTYPE_FEET    )] = {  2.00,  0.00,  0.60, -1.00 },
    [Chr(O.Classic,     R.Orc,      S.Male,   I.SetsDetails     )] = {  0.00,  0.02, -0.33,  0.00 },
    [Chr(O.Classic,     R.Orc,      S.Male,   I.SetsVendor      )] = {  0.50,  0.02, -0.25,  0.00 },
    [Chr(O.Classic,     R.Orc,      S.Female, I.INVTYPE_HEAD    )] = {  2.20,  0.02, -0.65, -0.50 },
    [Chr(O.Classic,     R.Orc,      S.Female, I.INVTYPE_SHOULDER)] = {  2.00, -0.25, -0.55, -0.25 },
    [Chr(O.Classic,     R.Orc,      S.Female, I.INVTYPE_CLOAK   )] = {  1.20,  0.00,  0.05,  BACK },
    [Chr(O.Classic,     R.Orc,      S.Female, I.INVTYPE_CHEST   )] = {  2.05,  0.00, -0.30, -0.25 },
    [Chr(O.Classic,     R.Orc,      S.Female, I.INVTYPE_ROBE    )] = {  1.10,  0.00,  0.15, -0.25 },
    [Chr(O.Classic,     R.Orc,      S.Female, I.INVTYPE_BODY    )] = {  2.05,  0.00, -0.30, -0.25 },
    [Chr(O.Classic,     R.Orc,      S.Female, I.INVTYPE_TABARD  )] = {  1.70,  0.00, -0.10, -0.25 },
    [Chr(O.Classic,     R.Orc,      S.Female, I.INVTYPE_WRIST   )] = {  2.40, -0.25, -0.11, -0.50 },
    [Chr(O.Classic,     R.Orc,      S.Female, I.INVTYPE_HAND    )] = {  2.20, -0.25, -0.04, -0.50 },
    [Chr(O.Classic,     R.Orc,      S.Female, I.INVTYPE_WAIST   )] = {  2.30,  0.00, -0.15, -0.25 },
    [Chr(O.Classic,     R.Orc,      S.Female, I.INVTYPE_LEGS    )] = {  1.45,  0.00,  0.35, -0.25 },
    [Chr(O.Classic,     R.Orc,      S.Female, I.INVTYPE_FEET    )] = {  1.95,  0.00,  0.63, -1.00 },
    [Chr(O.Classic,     R.Orc,      S.Female, I.SetsDetails     )] = {  0.00,  0.02, -0.28,  0.00 },
    [Chr(O.Classic,     R.Orc,      S.Female, I.SetsVendor      )] = {  1.00,  0.02, -0.20,  0.00 },
    [Chr(O.Classic,     R.Dwarf,    S.Male,   I.INVTYPE_HEAD    )] = {  1.60,  0.00, -0.30, -0.50 },
    [Chr(O.Classic,     R.Dwarf,    S.Male,   I.INVTYPE_SHOULDER)] = {  1.40, -0.30, -0.20, -0.25 },
    [Chr(O.Classic,     R.Dwarf,    S.Male,   I.INVTYPE_CLOAK   )] = {  1.00,  0.00,  0.20,  BACK },
    [Chr(O.Classic,     R.Dwarf,    S.Male,   I.INVTYPE_CHEST   )] = {  1.25,  0.00,  0.00, -0.25 },
    [Chr(O.Classic,     R.Dwarf,    S.Male,   I.INVTYPE_ROBE    )] = {  1.00,  0.00,  0.20, -0.25 },
    [Chr(O.Classic,     R.Dwarf,    S.Male,   I.INVTYPE_BODY    )] = {  1.25,  0.00,  0.00, -0.25 },
    [Chr(O.Classic,     R.Dwarf,    S.Male,   I.INVTYPE_TABARD  )] = {  1.25,  0.00,  0.15, -0.25 },
    [Chr(O.Classic,     R.Dwarf,    S.Male,   I.INVTYPE_WRIST   )] = {  1.90, -0.32,  0.20, -0.50 },
    [Chr(O.Classic,     R.Dwarf,    S.Male,   I.INVTYPE_HAND    )] = {  1.70, -0.33,  0.25, -0.50 },
    [Chr(O.Classic,     R.Dwarf,    S.Male,   I.INVTYPE_WAIST   )] = {  1.60,  0.00,  0.20, -0.25 },
    [Chr(O.Classic,     R.Dwarf,    S.Male,   I.INVTYPE_LEGS    )] = {  1.40,  0.00,  0.45, -0.25 },
    [Chr(O.Classic,     R.Dwarf,    S.Male,   I.INVTYPE_FEET    )] = {  1.40,  0.00,  0.60, -0.65 },
    [Chr(O.Classic,     R.Dwarf,    S.Male,   I.SetsDetails     )] = {  0.00,  0.00, -0.25,  0.00 },
    [Chr(O.Classic,     R.Dwarf,    S.Male,   I.SetsVendor      )] = {  0.50,  0.00,  0.00,  0.00 },
    [Chr(O.Classic,     R.Dwarf,    S.Female, I.INVTYPE_HEAD    )] = {  1.45, -0.02, -0.40, -0.50 },
    [Chr(O.Classic,     R.Dwarf,    S.Female, I.INVTYPE_SHOULDER)] = {  1.50, -0.25, -0.25, -0.25 },
    [Chr(O.Classic,     R.Dwarf,    S.Female, I.INVTYPE_CLOAK   )] = {  1.00, -0.05,  0.15,  BACK },
    [Chr(O.Classic,     R.Dwarf,    S.Female, I.INVTYPE_CHEST   )] = {  1.35, -0.05, -0.05, -0.25 },
    [Chr(O.Classic,     R.Dwarf,    S.Female, I.INVTYPE_ROBE    )] = {  1.00, -0.05,  0.20, -0.25 },
    [Chr(O.Classic,     R.Dwarf,    S.Female, I.INVTYPE_BODY    )] = {  1.35, -0.05, -0.05, -0.25 },
    [Chr(O.Classic,     R.Dwarf,    S.Female, I.INVTYPE_TABARD  )] = {  1.25, -0.03,  0.10, -0.25 },
    [Chr(O.Classic,     R.Dwarf,    S.Female, I.INVTYPE_WRIST   )] = {  1.75, -0.25,  0.10, -0.50 },
    [Chr(O.Classic,     R.Dwarf,    S.Female, I.INVTYPE_HAND    )] = {  1.65, -0.25,  0.13, -0.50 },
    [Chr(O.Classic,     R.Dwarf,    S.Female, I.INVTYPE_WAIST   )] = {  1.55, -0.02,  0.10, -0.25 },
    [Chr(O.Classic,     R.Dwarf,    S.Female, I.INVTYPE_LEGS    )] = {  1.35, -0.02,  0.37, -0.25 },
    [Chr(O.Classic,     R.Dwarf,    S.Female, I.INVTYPE_FEET    )] = {  1.50, -0.02,  0.57, -0.85 },
    [Chr(O.Classic,     R.Dwarf,    S.Female, I.SetsDetails     )] = {  0.00, -0.03, -0.20,  0.00 },
    [Chr(O.Classic,     R.Dwarf,    S.Female, I.SetsVendor      )] = {  0.50, -0.03,  0.00,  0.00 },
    [Chr(O.Classic,     R.NightElf, S.Male,   I.INVTYPE_HEAD    )] = {  3.20,  0.00, -0.90, -0.50 },
    [Chr(O.Classic,     R.NightElf, S.Male,   I.INVTYPE_SHOULDER)] = {  3.00, -0.30, -0.75, -0.25 },
    [Chr(O.Classic,     R.NightElf, S.Male,   I.INVTYPE_CLOAK   )] = {  2.05,  0.00,  0.00,  BACK },
    [Chr(O.Classic,     R.NightElf, S.Male,   I.INVTYPE_CHEST   )] = {  3.00, -0.05, -0.50, -0.25 },
    [Chr(O.Classic,     R.NightElf, S.Male,   I.INVTYPE_ROBE    )] = {  1.95, -0.05,  0.05, -0.25 },
    [Chr(O.Classic,     R.NightElf, S.Male,   I.INVTYPE_BODY    )] = {  3.00, -0.05, -0.50, -0.25 },
    [Chr(O.Classic,     R.NightElf, S.Male,   I.INVTYPE_TABARD  )] = {  2.60,  0.00, -0.20, -0.25 },
    [Chr(O.Classic,     R.NightElf, S.Male,   I.INVTYPE_WRIST   )] = {  3.50, -0.35, -0.23, -0.50 },
    [Chr(O.Classic,     R.NightElf, S.Male,   I.INVTYPE_HAND    )] = {  3.20, -0.35, -0.13, -0.50 },
    [Chr(O.Classic,     R.NightElf, S.Male,   I.INVTYPE_WAIST   )] = {  3.45, -0.01, -0.25, -0.25 },
    [Chr(O.Classic,     R.NightElf, S.Male,   I.INVTYPE_LEGS    )] = {  2.50, -0.05,  0.30, -0.25 },
    [Chr(O.Classic,     R.NightElf, S.Male,   I.INVTYPE_FEET    )] = {  3.00, -0.05,  0.64, -0.50 },
    [Chr(O.Classic,     R.NightElf, S.Male,   I.SetsDetails     )] = {  0.00,  0.00, -0.40,  0.00 },
    [Chr(O.Classic,     R.NightElf, S.Male,   I.SetsVendor      )] = {  1.50,  0.00, -0.25,  0.00 },
    [Chr(O.Classic,     R.NightElf, S.Female, I.INVTYPE_HEAD    )] = {  3.05, -0.02, -0.80, -0.50 },
    [Chr(O.Classic,     R.NightElf, S.Female, I.INVTYPE_SHOULDER)] = {  2.95, -0.23, -0.65, -0.25 },
    [Chr(O.Classic,     R.NightElf, S.Female, I.INVTYPE_CLOAK   )] = {  1.80,  0.00,  0.00,  BACK },
    [Chr(O.Classic,     R.NightElf, S.Female, I.INVTYPE_CHEST   )] = {  2.95, -0.02, -0.45, -0.25 },
    [Chr(O.Classic,     R.NightElf, S.Female, I.INVTYPE_ROBE    )] = {  1.65, -0.01,  0.10, -0.25 },
    [Chr(O.Classic,     R.NightElf, S.Female, I.INVTYPE_BODY    )] = {  2.95, -0.02, -0.45, -0.25 },
    [Chr(O.Classic,     R.NightElf, S.Female, I.INVTYPE_TABARD  )] = {  2.50,  0.00, -0.20, -0.25 },
    [Chr(O.Classic,     R.NightElf, S.Female, I.INVTYPE_WRIST   )] = {  3.25, -0.23, -0.20, -0.50 },
    [Chr(O.Classic,     R.NightElf, S.Female, I.INVTYPE_HAND    )] = {  3.05, -0.23, -0.15, -0.50 },
    [Chr(O.Classic,     R.NightElf, S.Female, I.INVTYPE_WAIST   )] = {  3.10,  0.00, -0.25, -0.25 },
    [Chr(O.Classic,     R.NightElf, S.Female, I.INVTYPE_LEGS    )] = {  2.05,  0.00,  0.30, -0.25 },
    [Chr(O.Classic,     R.NightElf, S.Female, I.INVTYPE_FEET    )] = {  2.70, -0.03,  0.66, -0.90 },
    [Chr(O.Classic,     R.NightElf, S.Female, I.SetsDetails     )] = {  0.00,  0.00, -0.33,  0.00 },
    [Chr(O.Classic,     R.NightElf, S.Female, I.SetsVendor      )] = {  1.25,  0.00, -0.25,  0.00 },
    [Chr(O.Classic,     R.Scourge,  S.Male,   I.INVTYPE_HEAD    )] = {  2.10, -0.05, -0.85, -0.50 },
    [Chr(O.Classic,     R.Scourge,  S.Male,   I.INVTYPE_SHOULDER)] = {  2.15, -0.35, -0.80, -0.25 },
    [Chr(O.Classic,     R.Scourge,  S.Male,   I.INVTYPE_CLOAK   )] = {  1.00, -0.06, -0.15,  BACK },
    [Chr(O.Classic,     R.Scourge,  S.Male,   I.INVTYPE_CHEST   )] = {  1.75, -0.10, -0.60, -0.25 },
    [Chr(O.Classic,     R.Scourge,  S.Male,   I.INVTYPE_ROBE    )] = {  0.80, -0.10, -0.05, -0.25 },
    [Chr(O.Classic,     R.Scourge,  S.Male,   I.INVTYPE_BODY    )] = {  1.75, -0.10, -0.60, -0.25 },
    [Chr(O.Classic,     R.Scourge,  S.Male,   I.INVTYPE_TABARD  )] = {  1.50, -0.08, -0.30, -0.25 },
    [Chr(O.Classic,     R.Scourge,  S.Male,   I.INVTYPE_WRIST   )] = {  2.35, -0.30, -0.30, -0.50 },
    [Chr(O.Classic,     R.Scourge,  S.Male,   I.INVTYPE_HAND    )] = {  2.05, -0.30, -0.25, -0.50 },
    [Chr(O.Classic,     R.Scourge,  S.Male,   I.INVTYPE_WAIST   )] = {  2.30, -0.10, -0.35, -0.25 },
    [Chr(O.Classic,     R.Scourge,  S.Male,   I.INVTYPE_LEGS    )] = {  1.40, -0.10,  0.20, -0.25 },
    [Chr(O.Classic,     R.Scourge,  S.Male,   I.INVTYPE_FEET    )] = {  2.00, -0.10,  0.45, -1.00 },
    [Chr(O.Classic,     R.Scourge,  S.Male,   I.SetsDetails     )] = {  0.00,  0.00, -0.33,  0.00 },
    [Chr(O.Classic,     R.Scourge,  S.Male,   I.SetsVendor      )] = {  1.00,  0.00, -0.25,  0.00 },
    [Chr(O.Classic,     R.Scourge,  S.Female, I.INVTYPE_HEAD    )] = {  2.20,  0.00, -0.75, -0.50 },
    [Chr(O.Classic,     R.Scourge,  S.Female, I.INVTYPE_SHOULDER)] = {  2.20, -0.20, -0.60, -0.25 },
    [Chr(O.Classic,     R.Scourge,  S.Female, I.INVTYPE_CLOAK   )] = {  1.30,  0.00,  0.05,  BACK },
    [Chr(O.Classic,     R.Scourge,  S.Female, I.INVTYPE_CHEST   )] = {  2.20, -0.02, -0.35, -0.25 },
    [Chr(O.Classic,     R.Scourge,  S.Female, I.INVTYPE_ROBE    )] = {  1.20,  0.00,  0.05, -0.25 },
    [Chr(O.Classic,     R.Scourge,  S.Female, I.INVTYPE_BODY    )] = {  2.20, -0.02, -0.35, -0.25 },
    [Chr(O.Classic,     R.Scourge,  S.Female, I.INVTYPE_TABARD  )] = {  2.00,  0.00, -0.20, -0.25 },
    [Chr(O.Classic,     R.Scourge,  S.Female, I.INVTYPE_WRIST   )] = {  2.60, -0.18, -0.20, -0.50 },
    [Chr(O.Classic,     R.Scourge,  S.Female, I.INVTYPE_HAND    )] = {  2.30, -0.18, -0.15, -0.50 },
    [Chr(O.Classic,     R.Scourge,  S.Female, I.INVTYPE_WAIST   )] = {  2.50,  0.00, -0.20, -0.25 },
    [Chr(O.Classic,     R.Scourge,  S.Female, I.INVTYPE_LEGS    )] = {  1.65,  0.00,  0.25, -0.25 },
    [Chr(O.Classic,     R.Scourge,  S.Female, I.INVTYPE_FEET    )] = {  2.10,  0.02,  0.45, -0.50 },
    [Chr(O.Classic,     R.Scourge,  S.Female, I.SetsDetails     )] = {  0.00,  0.00, -0.25,  0.00 },
    [Chr(O.Classic,     R.Scourge,  S.Female, I.SetsVendor      )] = {  0.75,  0.00, -0.15,  0.00 },
    [Chr(O.Classic,     R.Tauren,   S.Male,   I.INVTYPE_HEAD    )] = {  2.20,  0.20, -0.50, -0.50 },
    [Chr(O.Classic,     R.Tauren,   S.Male,   I.INVTYPE_SHOULDER)] = {  1.90, -0.45, -0.60, -0.25 },
    [Chr(O.Classic,     R.Tauren,   S.Male,   I.INVTYPE_CLOAK   )] = {  1.25,  0.00,  0.00,  BACK },
    [Chr(O.Classic,     R.Tauren,   S.Male,   I.INVTYPE_CHEST   )] = {  1.65,  0.00, -0.25, -0.25 },
    [Chr(O.Classic,     R.Tauren,   S.Male,   I.INVTYPE_ROBE    )] = {  1.35,  0.00,  0.05, -0.25 },
    [Chr(O.Classic,     R.Tauren,   S.Male,   I.INVTYPE_BODY    )] = {  1.65,  0.00, -0.25, -0.25 },
    [Chr(O.Classic,     R.Tauren,   S.Male,   I.INVTYPE_TABARD  )] = {  1.65,  0.00, -0.10, -0.25 },
    [Chr(O.Classic,     R.Tauren,   S.Male,   I.INVTYPE_WRIST   )] = {  2.75, -0.45, -0.05, -0.50 },
    [Chr(O.Classic,     R.Tauren,   S.Male,   I.INVTYPE_HAND    )] = {  2.30, -0.45,  0.05, -0.50 },
    [Chr(O.Classic,     R.Tauren,   S.Male,   I.INVTYPE_WAIST   )] = {  2.70, -0.02,  0.00, -0.25 },
    [Chr(O.Classic,     R.Tauren,   S.Male,   I.INVTYPE_LEGS    )] = {  2.25, -0.02,  0.40, -0.25 },
    [Chr(O.Classic,     R.Tauren,   S.Male,   I.INVTYPE_FEET    )] = {  2.40, -0.02,  0.60, -0.50 },
    [Chr(O.Classic,     R.Tauren,   S.Male,   I.SetsDetails     )] = {  0.00,  0.00, -0.33,  0.00 },
    [Chr(O.Classic,     R.Tauren,   S.Male,   I.SetsVendor      )] = {  0.75,  0.00, -0.25,  0.00 },
    [Chr(O.Classic,     R.Tauren,   S.Female, I.INVTYPE_HEAD    )] = {  2.10,  0.15, -0.35, -0.50 },
    [Chr(O.Classic,     R.Tauren,   S.Female, I.INVTYPE_SHOULDER)] = {  2.25, -0.30, -0.30, -0.25 },
    [Chr(O.Classic,     R.Tauren,   S.Female, I.INVTYPE_CLOAK   )] = {  1.25,  0.00,  0.20,  BACK },
    [Chr(O.Classic,     R.Tauren,   S.Female, I.INVTYPE_CHEST   )] = {  2.10,  0.00, -0.10, -0.25 },
    [Chr(O.Classic,     R.Tauren,   S.Female, I.INVTYPE_ROBE    )] = {  1.25,  0.00,  0.20, -0.25 },
    [Chr(O.Classic,     R.Tauren,   S.Female, I.INVTYPE_BODY    )] = {  2.10,  0.00, -0.10, -0.25 },
    [Chr(O.Classic,     R.Tauren,   S.Female, I.INVTYPE_TABARD  )] = {  1.50,  0.05,  0.15, -0.25 },
    [Chr(O.Classic,     R.Tauren,   S.Female, I.INVTYPE_WRIST   )] = {  2.60, -0.32,  0.25, -0.50 },
    [Chr(O.Classic,     R.Tauren,   S.Female, I.INVTYPE_HAND    )] = {  2.25, -0.30,  0.28, -0.50 },
    [Chr(O.Classic,     R.Tauren,   S.Female, I.INVTYPE_WAIST   )] = {  2.35,  0.00,  0.30, -0.25 },
    [Chr(O.Classic,     R.Tauren,   S.Female, I.INVTYPE_LEGS    )] = {  1.85,  0.00,  0.60, -0.25 },
    [Chr(O.Classic,     R.Tauren,   S.Female, I.INVTYPE_FEET    )] = {  2.20,  0.00,  0.90, -0.60 },
    [Chr(O.Classic,     R.Tauren,   S.Female, I.SetsDetails     )] = {  0.00,  0.00, -0.33,  0.00 },
    [Chr(O.Classic,     R.Tauren,   S.Female, I.SetsVendor      )] = {  0.75,  0.00, -0.15,  0.00 },
    [Chr(O.Classic,     R.Gnome,    S.Male,   I.INVTYPE_HEAD    )] = {  1.00,  0.00, -0.20, -0.50 },
    [Chr(O.Classic,     R.Gnome,    S.Male,   I.INVTYPE_SHOULDER)] = {  1.15, -0.22, -0.10, -0.25 },
    [Chr(O.Classic,     R.Gnome,    S.Male,   I.INVTYPE_CLOAK   )] = {  1.00,  0.00,  0.20,  BACK },
    [Chr(O.Classic,     R.Gnome,    S.Male,   I.INVTYPE_CHEST   )] = {  1.10, -0.02,  0.05, -0.25 },
    [Chr(O.Classic,     R.Gnome,    S.Male,   I.INVTYPE_ROBE    )] = {  1.00, -0.02,  0.15, -0.25 },
    [Chr(O.Classic,     R.Gnome,    S.Male,   I.INVTYPE_BODY    )] = {  1.10, -0.02,  0.05, -0.25 },
    [Chr(O.Classic,     R.Gnome,    S.Male,   I.INVTYPE_TABARD  )] = {  1.25,  0.00,  0.15, -0.25 },
    [Chr(O.Classic,     R.Gnome,    S.Male,   I.INVTYPE_WRIST   )] = {  1.50, -0.15,  0.15, -1.10 },
    [Chr(O.Classic,     R.Gnome,    S.Male,   I.INVTYPE_HAND    )] = {  1.50, -0.22,  0.17, -0.50 },
    [Chr(O.Classic,     R.Gnome,    S.Male,   I.INVTYPE_WAIST   )] = {  1.30,  0.00,  0.20, -0.25 },
    [Chr(O.Classic,     R.Gnome,    S.Male,   I.INVTYPE_LEGS    )] = {  1.25,  0.00,  0.32, -0.25 },
    [Chr(O.Classic,     R.Gnome,    S.Male,   I.INVTYPE_FEET    )] = {  1.35, -0.02,  0.40, -1.00 },
    [Chr(O.Classic,     R.Gnome,    S.Male,   I.SetsDetails     )] = {  0.00,  0.00, -0.15,  0.00 },
    [Chr(O.Classic,     R.Gnome,    S.Male,   I.SetsVendor      )] = {  0.50,  0.00,  0.00,  0.00 },
    [Chr(O.Classic,     R.Gnome,    S.Female, I.INVTYPE_HEAD    )] = {  0.90, -0.03, -0.20, -0.50 },
    [Chr(O.Classic,     R.Gnome,    S.Female, I.INVTYPE_SHOULDER)] = {  1.00, -0.20, -0.05, -0.25 },
    [Chr(O.Classic,     R.Gnome,    S.Female, I.INVTYPE_CLOAK   )] = {  0.90,  0.00,  0.20,  BACK },
    [Chr(O.Classic,     R.Gnome,    S.Female, I.INVTYPE_CHEST   )] = {  1.10, -0.02,  0.10, -0.25 },
    [Chr(O.Classic,     R.Gnome,    S.Female, I.INVTYPE_ROBE    )] = {  1.05, -0.02,  0.20, -0.25 },
    [Chr(O.Classic,     R.Gnome,    S.Female, I.INVTYPE_BODY    )] = {  1.10, -0.02,  0.10, -0.25 },
    [Chr(O.Classic,     R.Gnome,    S.Female, I.INVTYPE_TABARD  )] = {  1.15, -0.02,  0.18, -0.25 },
    [Chr(O.Classic,     R.Gnome,    S.Female, I.INVTYPE_WRIST   )] = {  1.35, -0.17,  0.17, -0.90 },
    [Chr(O.Classic,     R.Gnome,    S.Female, I.INVTYPE_HAND    )] = {  1.35, -0.19,  0.20, -0.50 },
    [Chr(O.Classic,     R.Gnome,    S.Female, I.INVTYPE_WAIST   )] = {  1.25, -0.02,  0.20, -0.25 },
    [Chr(O.Classic,     R.Gnome,    S.Female, I.INVTYPE_LEGS    )] = {  1.25, -0.02,  0.32, -0.25 },
    [Chr(O.Classic,     R.Gnome,    S.Female, I.INVTYPE_FEET    )] = {  1.25, -0.05,  0.40, -1.00 },
    [Chr(O.Classic,     R.Gnome,    S.Female, I.SetsDetails     )] = {  0.00,  0.00, -0.15,  0.00 },
    [Chr(O.Classic,     R.Gnome,    S.Female, I.SetsVendor      )] = {  0.50,  0.00,  0.00,  0.00 },
    [Chr(O.Classic,     R.Troll,    S.Male,   I.INVTYPE_HEAD    )] = {  2.90,  0.05, -1.00, -0.50 },
    [Chr(O.Classic,     R.Troll,    S.Male,   I.INVTYPE_SHOULDER)] = {  2.70, -0.35, -0.95, -0.25 },
    [Chr(O.Classic,     R.Troll,    S.Male,   I.INVTYPE_CLOAK   )] = {  1.50,  0.00, -0.25,  BACK },
    [Chr(O.Classic,     R.Troll,    S.Male,   I.INVTYPE_CHEST   )] = {  2.45,  0.00, -0.55, -0.25 },
    [Chr(O.Classic,     R.Troll,    S.Male,   I.INVTYPE_ROBE    )] = {  1.00,  0.00, -0.05, -0.25 },
    [Chr(O.Classic,     R.Troll,    S.Male,   I.INVTYPE_BODY    )] = {  2.45,  0.00, -0.55, -0.25 },
    [Chr(O.Classic,     R.Troll,    S.Male,   I.INVTYPE_TABARD  )] = {  2.00,  0.00, -0.30, -0.25 },
    [Chr(O.Classic,     R.Troll,    S.Male,   I.INVTYPE_WRIST   )] = {  3.25, -0.35, -0.13, -0.20 },
    [Chr(O.Classic,     R.Troll,    S.Male,   I.INVTYPE_HAND    )] = {  3.00, -0.35, -0.05,  0.05 },
    [Chr(O.Classic,     R.Troll,    S.Male,   I.INVTYPE_WAIST   )] = {  3.25, -0.01, -0.25, -0.25 },
    [Chr(O.Classic,     R.Troll,    S.Male,   I.INVTYPE_LEGS    )] = {  1.80,  0.00,  0.30, -0.25 },
    [Chr(O.Classic,     R.Troll,    S.Male,   I.INVTYPE_FEET    )] = {  2.80, -0.05,  0.70, -0.80 },
    [Chr(O.Classic,     R.Troll,    S.Male,   I.SetsDetails     )] = {  0.00, -0.02, -0.33,  0.00 },
    [Chr(O.Classic,     R.Troll,    S.Male,   I.SetsVendor      )] = {  0.75, -0.02, -0.15,  0.00 },
    [Chr(O.Classic,     R.Troll,    S.Female, I.INVTYPE_HEAD    )] = {  3.00, -0.05, -0.65, -0.50 },
    [Chr(O.Classic,     R.Troll,    S.Female, I.INVTYPE_SHOULDER)] = {  2.85, -0.30, -0.45, -0.25 },
    [Chr(O.Classic,     R.Troll,    S.Female, I.INVTYPE_CLOAK   )] = {  1.50, -0.05,  0.15,  BACK },
    [Chr(O.Classic,     R.Troll,    S.Female, I.INVTYPE_CHEST   )] = {  2.85, -0.05, -0.30, -0.25 },
    [Chr(O.Classic,     R.Troll,    S.Female, I.INVTYPE_ROBE    )] = {  1.40, -0.05,  0.20, -0.25 },
    [Chr(O.Classic,     R.Troll,    S.Female, I.INVTYPE_BODY    )] = {  2.85, -0.05, -0.30, -0.25 },
    [Chr(O.Classic,     R.Troll,    S.Female, I.INVTYPE_TABARD  )] = {  2.25, -0.05, -0.05, -0.25 },
    [Chr(O.Classic,     R.Troll,    S.Female, I.INVTYPE_WRIST   )] = {  3.10, -0.30,  0.02, -0.50 },
    [Chr(O.Classic,     R.Troll,    S.Female, I.INVTYPE_HAND    )] = {  2.85, -0.30,  0.07, -0.50 },
    [Chr(O.Classic,     R.Troll,    S.Female, I.INVTYPE_WAIST   )] = {  3.10, -0.05, -0.02, -0.25 },
    [Chr(O.Classic,     R.Troll,    S.Female, I.INVTYPE_LEGS    )] = {  2.10, -0.05,  0.45, -0.25 },
    [Chr(O.Classic,     R.Troll,    S.Female, I.INVTYPE_FEET    )] = {  2.85, -0.07,  0.78, -0.50 },
    [Chr(O.Classic,     R.Troll,    S.Female, I.SetsDetails     )] = {  0.00, -0.02, -0.33,  0.00 },
    [Chr(O.Classic,     R.Troll,    S.Female, I.SetsVendor      )] = {  1.25, -0.02, -0.10,  0.00 },
    [Chr(O.Classic,     R.BloodElf, S.Male,   I.INVTYPE_HEAD    )] = {  2.85,  0.02, -0.85, -0.30 },
    [Chr(O.Classic,     R.BloodElf, S.Male,   I.INVTYPE_SHOULDER)] = {  2.50, -0.25, -0.75, -0.25 },
    [Chr(O.Classic,     R.BloodElf, S.Male,   I.INVTYPE_CLOAK   )] = {  1.80, -0.10, -0.10,  BACK },
    [Chr(O.Classic,     R.BloodElf, S.Male,   I.INVTYPE_CHEST   )] = {  2.45,  0.00, -0.40,  0.10 },
    [Chr(O.Classic,     R.BloodElf, S.Male,   I.INVTYPE_ROBE    )] = {  1.50, -0.05,  0.05,  0.10 },
    [Chr(O.Classic,     R.BloodElf, S.Male,   I.INVTYPE_BODY    )] = {  2.45,  0.00, -0.40,  0.10 },
    [Chr(O.Classic,     R.BloodElf, S.Male,   I.INVTYPE_TABARD  )] = {  2.15,  0.00, -0.20,  0.10 },
    [Chr(O.Classic,     R.BloodElf, S.Male,   I.INVTYPE_WRIST   )] = {  3.00, -0.25, -0.30, -0.35 },
    [Chr(O.Classic,     R.BloodElf, S.Male,   I.INVTYPE_HAND    )] = {  2.85, -0.22, -0.25, -0.50 },
    [Chr(O.Classic,     R.BloodElf, S.Male,   I.INVTYPE_WAIST   )] = {  2.85,  0.02, -0.30,  0.10 },
    [Chr(O.Classic,     R.BloodElf, S.Male,   I.INVTYPE_LEGS    )] = {  2.00, -0.10,  0.20,  0.10 },
    [Chr(O.Classic,     R.BloodElf, S.Male,   I.INVTYPE_FEET    )] = {  2.45, -0.10,  0.47, -0.70 },
    [Chr(O.Classic,     R.BloodElf, S.Male,   I.SetsDetails     )] = {  0.00,  0.00, -0.33,  0.00 },
    [Chr(O.Classic,     R.BloodElf, S.Male,   I.SetsVendor      )] = {  1.25,  0.00, -0.25,  0.00 },
    [Chr(O.Classic,     R.BloodElf, S.Female, I.INVTYPE_HEAD    )] = {  2.35,  0.03, -0.65, -0.50 },
    [Chr(O.Classic,     R.BloodElf, S.Female, I.INVTYPE_SHOULDER)] = {  2.45, -0.13, -0.55, -0.25 },
    [Chr(O.Classic,     R.BloodElf, S.Female, I.INVTYPE_CLOAK   )] = {  1.30,  0.03,  0.00,  BACK },
    [Chr(O.Classic,     R.BloodElf, S.Female, I.INVTYPE_CHEST   )] = {  2.30,  0.03, -0.35, -0.25 },
    [Chr(O.Classic,     R.BloodElf, S.Female, I.INVTYPE_ROBE    )] = {  1.20,  0.02,  0.10, -0.25 },
    [Chr(O.Classic,     R.BloodElf, S.Female, I.INVTYPE_BODY    )] = {  2.30,  0.03, -0.35, -0.25 },
    [Chr(O.Classic,     R.BloodElf, S.Female, I.INVTYPE_TABARD  )] = {  1.95,  0.02, -0.17, -0.25 },
    [Chr(O.Classic,     R.BloodElf, S.Female, I.INVTYPE_WRIST   )] = {  2.50, -0.15, -0.15, -0.50 },
    [Chr(O.Classic,     R.BloodElf, S.Female, I.INVTYPE_HAND    )] = {  2.30, -0.15, -0.10, -0.50 },
    [Chr(O.Classic,     R.BloodElf, S.Female, I.INVTYPE_WAIST   )] = {  2.40,  0.05, -0.20, -0.25 },
    [Chr(O.Classic,     R.BloodElf, S.Female, I.INVTYPE_LEGS    )] = {  1.55,  0.00,  0.25, -0.25 },
    [Chr(O.Classic,     R.BloodElf, S.Female, I.INVTYPE_FEET    )] = {  2.05,  0.00,  0.55, -0.90 },
    [Chr(O.Classic,     R.BloodElf, S.Female, I.SetsDetails     )] = {  0.00,  0.03, -0.33,  0.00 },
    [Chr(O.Classic,     R.BloodElf, S.Female, I.SetsVendor      )] = {  1.00,  0.03, -0.15,  0.00 },
    [Chr(O.Classic,     R.Draenei,  S.Male,   I.INVTYPE_HEAD    )] = {  3.20, -0.05, -0.55, -0.50 },
    [Chr(O.Classic,     R.Draenei,  S.Male,   I.INVTYPE_SHOULDER)] = {  2.80, -0.50, -0.40, -0.25 },
    [Chr(O.Classic,     R.Draenei,  S.Male,   I.INVTYPE_CLOAK   )] = {  2.05, -0.10,  0.20,  BACK },
    [Chr(O.Classic,     R.Draenei,  S.Male,   I.INVTYPE_CHEST   )] = {  2.50, -0.10, -0.25, -0.25 },
    [Chr(O.Classic,     R.Draenei,  S.Male,   I.INVTYPE_ROBE    )] = {  1.80, -0.10,  0.30, -0.25 },
    [Chr(O.Classic,     R.Draenei,  S.Male,   I.INVTYPE_BODY    )] = {  2.50, -0.10, -0.25, -0.25 },
    [Chr(O.Classic,     R.Draenei,  S.Male,   I.INVTYPE_TABARD  )] = {  2.50, -0.10,  0.10, -0.25 },
    [Chr(O.Classic,     R.Draenei,  S.Male,   I.INVTYPE_WRIST   )] = {  3.50, -0.45,  0.22, -0.50 },
    [Chr(O.Classic,     R.Draenei,  S.Male,   I.INVTYPE_HAND    )] = {  3.20, -0.45,  0.25, -0.50 },
    [Chr(O.Classic,     R.Draenei,  S.Male,   I.INVTYPE_WAIST   )] = {  3.20, -0.10,  0.25, -0.25 },
    [Chr(O.Classic,     R.Draenei,  S.Male,   I.INVTYPE_LEGS    )] = {  2.55, -0.10,  0.65, -0.50 },
    [Chr(O.Classic,     R.Draenei,  S.Male,   I.INVTYPE_FEET    )] = {  2.95, -0.10,  1.00, -0.80 },
    [Chr(O.Classic,     R.Draenei,  S.Male,   I.SetsDetails     )] = {  0.00, -0.10, -0.40,  0.00 },
    [Chr(O.Classic,     R.Draenei,  S.Male,   I.SetsVendor      )] = {  1.25, -0.06, -0.15,  0.00 },
    [Chr(O.Classic,     R.Draenei,  S.Female, I.INVTYPE_HEAD    )] = {  2.75,  0.00, -0.90, -0.50 },
    [Chr(O.Classic,     R.Draenei,  S.Female, I.INVTYPE_SHOULDER)] = {  3.00, -0.25, -0.75, -0.25 },
    [Chr(O.Classic,     R.Draenei,  S.Female, I.INVTYPE_CLOAK   )] = {  2.00,  0.00, -0.10,  BACK },
    [Chr(O.Classic,     R.Draenei,  S.Female, I.INVTYPE_CHEST   )] = {  2.80, -0.03, -0.45, -0.25 },
    [Chr(O.Classic,     R.Draenei,  S.Female, I.INVTYPE_ROBE    )] = {  1.60, -0.00,  0.10, -0.25 },
    [Chr(O.Classic,     R.Draenei,  S.Female, I.INVTYPE_BODY    )] = {  2.80, -0.03, -0.45, -0.25 },
    [Chr(O.Classic,     R.Draenei,  S.Female, I.INVTYPE_TABARD  )] = {  2.45, -0.03, -0.25, -0.25 },
    [Chr(O.Classic,     R.Draenei,  S.Female, I.INVTYPE_WRIST   )] = {  3.20, -0.22, -0.30, -0.50 },
    [Chr(O.Classic,     R.Draenei,  S.Female, I.INVTYPE_HAND    )] = {  2.90, -0.23, -0.25, -0.50 },
    [Chr(O.Classic,     R.Draenei,  S.Female, I.INVTYPE_WAIST   )] = {  3.00, -0.02, -0.30, -0.25 },
    [Chr(O.Classic,     R.Draenei,  S.Female, I.INVTYPE_LEGS    )] = {  2.10, -0.02,  0.30, -0.25 },
    [Chr(O.Classic,     R.Draenei,  S.Female, I.INVTYPE_FEET    )] = {  2.70, -0.03,  0.55, -0.80 },
    [Chr(O.Classic,     R.Draenei,  S.Female, I.SetsDetails     )] = {  0.00,  0.00, -0.33,  0.00 },
    [Chr(O.Classic,     R.Draenei,  S.Female, I.SetsVendor      )] = {  1.25,  0.00, -0.33,  0.00 },
    -- HD2017
    [Chr(O.HD2017,      R.Human,    S.Male,   I.INVTYPE_HEAD    )] = {  2.25,  0.05, -0.75, -0.50 },
    [Chr(O.HD2017,      R.Human,    S.Male,   I.INVTYPE_SHOULDER)] = {  2.00, -0.25, -0.65, -0.25 },
    [Chr(O.HD2017,      R.Human,    S.Male,   I.INVTYPE_CLOAK   )] = {  1.30,  0.02,  0.00,  BACK },
    [Chr(O.HD2017,      R.Human,    S.Male,   I.INVTYPE_CHEST   )] = {  1.90,  0.00, -0.45, -0.25 },
    [Chr(O.HD2017,      R.Human,    S.Male,   I.INVTYPE_ROBE    )] = {  1.10,  0.00,  0.05, -0.25 },
    [Chr(O.HD2017,      R.Human,    S.Male,   I.INVTYPE_BODY    )] = {  1.90,  0.00, -0.45, -0.25 },
    [Chr(O.HD2017,      R.Human,    S.Male,   I.INVTYPE_TABARD  )] = {  1.50,  0.00, -0.15, -0.25 },
    [Chr(O.HD2017,      R.Human,    S.Male,   I.INVTYPE_WRIST   )] = {  2.45, -0.25, -0.15, -0.50 },
    [Chr(O.HD2017,      R.Human,    S.Male,   I.INVTYPE_HAND    )] = {  2.20, -0.25, -0.10, -0.50 },
    [Chr(O.HD2017,      R.Human,    S.Male,   I.INVTYPE_WAIST   )] = {  2.20,  0.02, -0.20, -0.25 },
    [Chr(O.HD2017,      R.Human,    S.Male,   I.INVTYPE_LEGS    )] = {  1.60,  0.00,  0.25, -0.25 },
    [Chr(O.HD2017,      R.Human,    S.Male,   I.INVTYPE_FEET    )] = {  2.00,  0.05,  0.52, -0.80 },
    [Chr(O.HD2017,      R.Human,    S.Male,   I.SetsDetails     )] = {  0.00,  0.02, -0.33,  0.00 },
    [Chr(O.HD2017,      R.Human,    S.Male,   I.SetsVendor      )] = {  0.75,  0.02, -0.25,  0.00 },
    [Chr(O.HD2017,      R.Human,    S.Female, I.INVTYPE_HEAD    )] = {  1.85,  0.02, -0.67, -0.50 },
    [Chr(O.HD2017,      R.Human,    S.Female, I.INVTYPE_SHOULDER)] = {  1.90, -0.15, -0.60, -0.25 },
    [Chr(O.HD2017,      R.Human,    S.Female, I.INVTYPE_CLOAK   )] = {  0.95,  0.01, -0.10,  BACK },
    [Chr(O.HD2017,      R.Human,    S.Female, I.INVTYPE_CHEST   )] = {  1.75,  0.01, -0.40, -0.25 },
    [Chr(O.HD2017,      R.Human,    S.Female, I.INVTYPE_ROBE    )] = {  0.70,  0.01,  0.05, -0.25 },
    [Chr(O.HD2017,      R.Human,    S.Female, I.INVTYPE_BODY    )] = {  1.75,  0.01, -0.40, -0.25 },
    [Chr(O.HD2017,      R.Human,    S.Female, I.INVTYPE_TABARD  )] = {  1.30,  0.00, -0.15, -0.25 },
    [Chr(O.HD2017,      R.Human,    S.Female, I.INVTYPE_WRIST   )] = {  2.00, -0.16, -0.18, -0.50 },
    [Chr(O.HD2017,      R.Human,    S.Female, I.INVTYPE_HAND    )] = {  1.85, -0.16, -0.14, -0.50 },
    [Chr(O.HD2017,      R.Human,    S.Female, I.INVTYPE_WAIST   )] = {  1.85,  0.02, -0.20, -0.25 },
    [Chr(O.HD2017,      R.Human,    S.Female, I.INVTYPE_LEGS    )] = {  1.15,  0.00,  0.22, -0.25 },
    [Chr(O.HD2017,      R.Human,    S.Female, I.INVTYPE_FEET    )] = {  1.65,  0.03,  0.50, -0.35 },
    [Chr(O.HD2017,      R.Human,    S.Female, I.SetsDetails     )] = { -0.25,  0.02, -0.28,  0.00 },
    [Chr(O.HD2017,      R.Human,    S.Female, I.SetsVendor      )] = {  0.33,  0.02, -0.25,  0.00 },
    [Chr(O.HD2017,      R.Orc,      S.Male,   I.INVTYPE_HEAD    )] = {  2.35,  0.10, -0.85, -0.50 },
    [Chr(O.HD2017,      R.Orc,      S.Male,   I.INVTYPE_SHOULDER)] = {  2.00, -0.45, -0.80, -0.25 },
    [Chr(O.HD2017,      R.Orc,      S.Male,   I.INVTYPE_CLOAK   )] = {  1.15,  0.02, -0.05,  BACK },
    [Chr(O.HD2017,      R.Orc,      S.Male,   I.INVTYPE_CHEST   )] = {  1.75,  0.00, -0.50, -0.25 },
    [Chr(O.HD2017,      R.Orc,      S.Male,   I.INVTYPE_ROBE    )] = {  1.20,  0.00,  0.00, -0.25 },
    [Chr(O.HD2017,      R.Orc,      S.Male,   I.INVTYPE_BODY    )] = {  1.75,  0.00, -0.50, -0.25 },
    [Chr(O.HD2017,      R.Orc,      S.Male,   I.INVTYPE_TABARD  )] = {  1.80,  0.00, -0.20, -0.25 },
    [Chr(O.HD2017,      R.Orc,      S.Male,   I.INVTYPE_WRIST   )] = {  2.70, -0.40, -0.15, -0.50 },
    [Chr(O.HD2017,      R.Orc,      S.Male,   I.INVTYPE_HAND    )] = {  2.40, -0.40, -0.05, -0.50 },
    [Chr(O.HD2017,      R.Orc,      S.Male,   I.INVTYPE_WAIST   )] = {  2.40,  0.00, -0.25, -0.25 },
    [Chr(O.HD2017,      R.Orc,      S.Male,   I.INVTYPE_LEGS    )] = {  1.75,  0.00,  0.25, -0.25 },
    [Chr(O.HD2017,      R.Orc,      S.Male,   I.INVTYPE_FEET    )] = {  2.00,  0.00,  0.55, -1.00 },
    [Chr(O.HD2017,      R.Orc,      S.Male,   I.SetsDetails     )] = {  0.00,  0.02, -0.33,  0.00 },
    [Chr(O.HD2017,      R.Orc,      S.Male,   I.SetsVendor      )] = {  0.50,  0.02, -0.15,  0.00 },
    [Chr(O.HD2017,      R.Orc,      S.Female, I.INVTYPE_HEAD    )] = {  2.15,  0.02, -0.65, -0.50 },
    [Chr(O.HD2017,      R.Orc,      S.Female, I.INVTYPE_SHOULDER)] = {  2.00, -0.25, -0.55, -0.25 },
    [Chr(O.HD2017,      R.Orc,      S.Female, I.INVTYPE_CLOAK   )] = {  1.20,  0.00,  0.05,  BACK },
    [Chr(O.HD2017,      R.Orc,      S.Female, I.INVTYPE_CHEST   )] = {  2.05,  0.00, -0.30, -0.25 },
    [Chr(O.HD2017,      R.Orc,      S.Female, I.INVTYPE_ROBE    )] = {  1.10,  0.00,  0.15, -0.25 },
    [Chr(O.HD2017,      R.Orc,      S.Female, I.INVTYPE_BODY    )] = {  2.05,  0.00, -0.30, -0.25 },
    [Chr(O.HD2017,      R.Orc,      S.Female, I.INVTYPE_TABARD  )] = {  1.70,  0.00, -0.10, -0.25 },
    [Chr(O.HD2017,      R.Orc,      S.Female, I.INVTYPE_WRIST   )] = {  2.40, -0.25, -0.11, -0.50 },
    [Chr(O.HD2017,      R.Orc,      S.Female, I.INVTYPE_HAND    )] = {  2.20, -0.25, -0.04, -0.50 },
    [Chr(O.HD2017,      R.Orc,      S.Female, I.INVTYPE_WAIST   )] = {  2.30,  0.00, -0.15, -0.25 },
    [Chr(O.HD2017,      R.Orc,      S.Female, I.INVTYPE_LEGS    )] = {  1.45,  0.00,  0.35, -0.25 },
    [Chr(O.HD2017,      R.Orc,      S.Female, I.INVTYPE_FEET    )] = {  1.95,  0.00,  0.63, -1.00 },
    [Chr(O.HD2017,      R.Orc,      S.Female, I.SetsDetails     )] = {  0.00,  0.02, -0.28,  0.00 },
    [Chr(O.HD2017,      R.Orc,      S.Female, I.SetsVendor      )] = {  0.75,  0.02, -0.20,  0.00 },
    [Chr(O.HD2017,      R.Dwarf,    S.Male,   I.INVTYPE_HEAD    )] = {  2.65,  0.00, -0.60, -0.50 },
    [Chr(O.HD2017,      R.Dwarf,    S.Male,   I.INVTYPE_SHOULDER)] = {  2.55, -0.30, -0.55, -0.25 },
    [Chr(O.HD2017,      R.Dwarf,    S.Male,   I.INVTYPE_CLOAK   )] = {  2.10,  0.00, -0.10,  BACK },
    [Chr(O.HD2017,      R.Dwarf,    S.Male,   I.INVTYPE_CHEST   )] = {  2.25,  0.00, -0.30, -0.25 },
    [Chr(O.HD2017,      R.Dwarf,    S.Male,   I.INVTYPE_ROBE    )] = {  2.05,  0.00,  0.00, -0.25 },
    [Chr(O.HD2017,      R.Dwarf,    S.Male,   I.INVTYPE_BODY    )] = {  2.25,  0.00, -0.30, -0.25 },
    [Chr(O.HD2017,      R.Dwarf,    S.Male,   I.INVTYPE_TABARD  )] = {  2.40,  0.00, -0.15, -0.25 },
    [Chr(O.HD2017,      R.Dwarf,    S.Male,   I.INVTYPE_WRIST   )] = {  2.95, -0.30, -0.13, -0.50 },
    [Chr(O.HD2017,      R.Dwarf,    S.Male,   I.INVTYPE_HAND    )] = {  2.75, -0.32, -0.07, -0.50 },
    [Chr(O.HD2017,      R.Dwarf,    S.Male,   I.INVTYPE_WAIST   )] = {  2.70,  0.00, -0.10, -0.25 },
    [Chr(O.HD2017,      R.Dwarf,    S.Male,   I.INVTYPE_LEGS    )] = {  2.50, -0.01,  0.15, -0.25 },
    [Chr(O.HD2017,      R.Dwarf,    S.Male,   I.INVTYPE_FEET    )] = {  2.45, -0.05,  0.30, -0.85 },
    [Chr(O.HD2017,      R.Dwarf,    S.Male,   I.SetsDetails     )] = {  1.00,  0.00, -0.33,  0.00 },
    [Chr(O.HD2017,      R.Dwarf,    S.Male,   I.SetsVendor      )] = {  1.50,  0.00, -0.15,  0.00 },
    [Chr(O.HD2017,      R.Dwarf,    S.Male,   I.DressUp         )] = {  1.00,  0.00, -0.08,  0.00 },
    [Chr(O.HD2017,      R.Dwarf,    S.Female, I.INVTYPE_HEAD    )] = {  1.35, -0.02, -0.40, -0.50 },
    [Chr(O.HD2017,      R.Dwarf,    S.Female, I.INVTYPE_SHOULDER)] = {  1.50, -0.25, -0.25, -0.25 },
    [Chr(O.HD2017,      R.Dwarf,    S.Female, I.INVTYPE_CLOAK   )] = {  1.00, -0.05,  0.12,  BACK },
    [Chr(O.HD2017,      R.Dwarf,    S.Female, I.INVTYPE_CHEST   )] = {  1.35, -0.04, -0.05, -0.25 },
    [Chr(O.HD2017,      R.Dwarf,    S.Female, I.INVTYPE_ROBE    )] = {  0.90, -0.05,  0.20, -0.25 },
    [Chr(O.HD2017,      R.Dwarf,    S.Female, I.INVTYPE_BODY    )] = {  1.35, -0.04, -0.05, -0.25 },
    [Chr(O.HD2017,      R.Dwarf,    S.Female, I.INVTYPE_TABARD  )] = {  1.20, -0.02,  0.10, -0.25 },
    [Chr(O.HD2017,      R.Dwarf,    S.Female, I.INVTYPE_WRIST   )] = {  1.70, -0.25,  0.10, -0.50 },
    [Chr(O.HD2017,      R.Dwarf,    S.Female, I.INVTYPE_HAND    )] = {  1.60, -0.25,  0.13, -0.50 },
    [Chr(O.HD2017,      R.Dwarf,    S.Female, I.INVTYPE_WAIST   )] = {  1.50, -0.02,  0.07, -0.25 },
    [Chr(O.HD2017,      R.Dwarf,    S.Female, I.INVTYPE_LEGS    )] = {  1.20, -0.02,  0.35, -0.25 },
    [Chr(O.HD2017,      R.Dwarf,    S.Female, I.INVTYPE_FEET    )] = {  1.45, -0.02,  0.57, -0.85 },
    [Chr(O.HD2017,      R.Dwarf,    S.Female, I.SetsDetails     )] = {  0.00, -0.03, -0.15,  0.00 },
    [Chr(O.HD2017,      R.Dwarf,    S.Female, I.SetsVendor      )] = {  0.25, -0.03, -0.05,  0.00 },
    [Chr(O.HD2017,      R.Dwarf,    S.Female, I.DressUp         )] = { -0.20, -0.03,  0.03,  0.00 },
    [Chr(O.HD2017,      R.NightElf, S.Male,   I.INVTYPE_HEAD    )] = {  3.25,  0.00, -0.90, -0.50 },
    [Chr(O.HD2017,      R.NightElf, S.Male,   I.INVTYPE_SHOULDER)] = {  3.05, -0.30, -0.80, -0.25 },
    [Chr(O.HD2017,      R.NightElf, S.Male,   I.INVTYPE_CLOAK   )] = {  2.05,  0.00,  0.00,  BACK },
    [Chr(O.HD2017,      R.NightElf, S.Male,   I.INVTYPE_CHEST   )] = {  3.00, -0.05, -0.50, -0.25 },
    [Chr(O.HD2017,      R.NightElf, S.Male,   I.INVTYPE_ROBE    )] = {  1.95, -0.05,  0.05, -0.25 },
    [Chr(O.HD2017,      R.NightElf, S.Male,   I.INVTYPE_BODY    )] = {  3.00, -0.05, -0.50, -0.25 },
    [Chr(O.HD2017,      R.NightElf, S.Male,   I.INVTYPE_TABARD  )] = {  2.60,  0.00, -0.20, -0.25 },
    [Chr(O.HD2017,      R.NightElf, S.Male,   I.INVTYPE_WRIST   )] = {  3.50, -0.35, -0.23, -0.50 },
    [Chr(O.HD2017,      R.NightElf, S.Male,   I.INVTYPE_HAND    )] = {  3.20, -0.35, -0.13, -0.50 },
    [Chr(O.HD2017,      R.NightElf, S.Male,   I.INVTYPE_WAIST   )] = {  3.45, -0.01, -0.25, -0.25 },
    [Chr(O.HD2017,      R.NightElf, S.Male,   I.INVTYPE_LEGS    )] = {  2.50, -0.05,  0.30, -0.25 },
    [Chr(O.HD2017,      R.NightElf, S.Male,   I.INVTYPE_FEET    )] = {  3.00, -0.05,  0.64, -0.50 },
    [Chr(O.HD2017,      R.NightElf, S.Male,   I.SetsDetails     )] = {  0.50,  0.00, -0.33,  0.00 },
    [Chr(O.HD2017,      R.NightElf, S.Male,   I.SetsVendor      )] = {  1.50,  0.00, -0.25,  0.00 },
    [Chr(O.HD2017,      R.NightElf, S.Female, I.INVTYPE_HEAD    )] = {  3.20, -0.02, -0.80, -0.50 },
    [Chr(O.HD2017,      R.NightElf, S.Female, I.INVTYPE_SHOULDER)] = {  3.15, -0.23, -0.65, -0.25 },
    [Chr(O.HD2017,      R.NightElf, S.Female, I.INVTYPE_CLOAK   )] = {  2.00,  0.00,  0.00,  BACK },
    [Chr(O.HD2017,      R.NightElf, S.Female, I.INVTYPE_CHEST   )] = {  3.15, -0.02, -0.45, -0.25 },
    [Chr(O.HD2017,      R.NightElf, S.Female, I.INVTYPE_ROBE    )] = {  1.85, -0.01,  0.10, -0.25 },
    [Chr(O.HD2017,      R.NightElf, S.Female, I.INVTYPE_BODY    )] = {  3.15, -0.02, -0.45, -0.25 },
    [Chr(O.HD2017,      R.NightElf, S.Female, I.INVTYPE_TABARD  )] = {  2.70,  0.00, -0.20, -0.25 },
    [Chr(O.HD2017,      R.NightElf, S.Female, I.INVTYPE_WRIST   )] = {  3.45, -0.23, -0.20, -0.50 },
    [Chr(O.HD2017,      R.NightElf, S.Female, I.INVTYPE_HAND    )] = {  3.25, -0.23, -0.15, -0.50 },
    [Chr(O.HD2017,      R.NightElf, S.Female, I.INVTYPE_WAIST   )] = {  3.30,  0.00, -0.25, -0.25 },
    [Chr(O.HD2017,      R.NightElf, S.Female, I.INVTYPE_LEGS    )] = {  2.35,  0.00,  0.30, -0.25 },
    [Chr(O.HD2017,      R.NightElf, S.Female, I.INVTYPE_FEET    )] = {  2.90, -0.03,  0.66, -0.90 },
    [Chr(O.HD2017,      R.NightElf, S.Female, I.SetsDetails     )] = {  0.50,  0.00, -0.33,  0.00 },
    [Chr(O.HD2017,      R.NightElf, S.Female, I.SetsVendor      )] = {  1.50,  0.00, -0.25,  0.00 },
    [Chr(O.HD2017,      R.Scourge,  S.Male,   I.INVTYPE_HEAD    )] = {  2.10, -0.05, -0.85, -0.50 },
    [Chr(O.HD2017,      R.Scourge,  S.Male,   I.INVTYPE_SHOULDER)] = {  2.20, -0.35, -0.85, -0.05 },
    [Chr(O.HD2017,      R.Scourge,  S.Male,   I.INVTYPE_CLOAK   )] = {  1.00, -0.06, -0.15,  BACK },
    [Chr(O.HD2017,      R.Scourge,  S.Male,   I.INVTYPE_CHEST   )] = {  1.75, -0.10, -0.60, -0.25 },
    [Chr(O.HD2017,      R.Scourge,  S.Male,   I.INVTYPE_ROBE    )] = {  0.80, -0.10, -0.05, -0.25 },
    [Chr(O.HD2017,      R.Scourge,  S.Male,   I.INVTYPE_BODY    )] = {  1.75, -0.10, -0.60, -0.25 },
    [Chr(O.HD2017,      R.Scourge,  S.Male,   I.INVTYPE_TABARD  )] = {  1.50, -0.08, -0.30, -0.25 },
    [Chr(O.HD2017,      R.Scourge,  S.Male,   I.INVTYPE_WRIST   )] = {  2.35, -0.30, -0.30, -0.50 },
    [Chr(O.HD2017,      R.Scourge,  S.Male,   I.INVTYPE_HAND    )] = {  2.05, -0.30, -0.25, -0.50 },
    [Chr(O.HD2017,      R.Scourge,  S.Male,   I.INVTYPE_WAIST   )] = {  2.30, -0.10, -0.35, -0.25 },
    [Chr(O.HD2017,      R.Scourge,  S.Male,   I.INVTYPE_LEGS    )] = {  1.40, -0.10,  0.20, -0.25 },
    [Chr(O.HD2017,      R.Scourge,  S.Male,   I.INVTYPE_FEET    )] = {  2.00, -0.10,  0.50, -1.00 },
    [Chr(O.HD2017,      R.Scourge,  S.Male,   I.SetsDetails     )] = {  0.00,  0.00, -0.33,  0.00 },
    [Chr(O.HD2017,      R.Scourge,  S.Male,   I.SetsVendor      )] = {  0.75,  0.00, -0.20,  0.00 },
    [Chr(O.HD2017,      R.Scourge,  S.Female, I.INVTYPE_HEAD    )] = {  3.10,  0.00, -0.65, -0.50 },
    [Chr(O.HD2017,      R.Scourge,  S.Female, I.INVTYPE_SHOULDER)] = {  3.10, -0.20, -0.55, -0.25 },
    [Chr(O.HD2017,      R.Scourge,  S.Female, I.INVTYPE_CLOAK   )] = {  2.15,  0.00,  0.05,  BACK },
    [Chr(O.HD2017,      R.Scourge,  S.Female, I.INVTYPE_CHEST   )] = {  3.05, -0.02, -0.35, -0.25 },
    [Chr(O.HD2017,      R.Scourge,  S.Female, I.INVTYPE_ROBE    )] = {  2.00,  0.00,  0.10, -0.25 },
    [Chr(O.HD2017,      R.Scourge,  S.Female, I.INVTYPE_BODY    )] = {  3.05, -0.02, -0.35, -0.25 },
    [Chr(O.HD2017,      R.Scourge,  S.Female, I.INVTYPE_TABARD  )] = {  2.70,  0.00, -0.15, -0.25 },
    [Chr(O.HD2017,      R.Scourge,  S.Female, I.INVTYPE_WRIST   )] = {  3.30, -0.18, -0.15, -0.50 },
    [Chr(O.HD2017,      R.Scourge,  S.Female, I.INVTYPE_HAND    )] = {  3.10, -0.18, -0.10, -0.50 },
    [Chr(O.HD2017,      R.Scourge,  S.Female, I.INVTYPE_WAIST   )] = {  3.25,  0.00, -0.15, -0.25 },
    [Chr(O.HD2017,      R.Scourge,  S.Female, I.INVTYPE_LEGS    )] = {  2.50,  0.00,  0.29, -0.25 },
    [Chr(O.HD2017,      R.Scourge,  S.Female, I.INVTYPE_FEET    )] = {  2.90,  0.02,  0.55, -0.50 },
    [Chr(O.HD2017,      R.Scourge,  S.Female, I.SetsDetails     )] = {  1.00,  0.00, -0.25,  0.00 },
    [Chr(O.HD2017,      R.Scourge,  S.Female, I.SetsVendor      )] = {  1.75,  0.00, -0.15,  0.00 },
    [Chr(O.HD2017,      R.Tauren,   S.Male,   I.INVTYPE_HEAD    )] = {  3.10,  0.25, -0.50, -0.50 },
    [Chr(O.HD2017,      R.Tauren,   S.Male,   I.INVTYPE_SHOULDER)] = {  2.75, -0.45, -0.55, -0.25 },
    [Chr(O.HD2017,      R.Tauren,   S.Male,   I.INVTYPE_CLOAK   )] = {  2.25, -0.02,  0.00,  BACK },
    [Chr(O.HD2017,      R.Tauren,   S.Male,   I.INVTYPE_CHEST   )] = {  2.75,  0.00, -0.25, -0.25 },
    [Chr(O.HD2017,      R.Tauren,   S.Male,   I.INVTYPE_ROBE    )] = {  2.25,  0.00,  0.05, -0.25 },
    [Chr(O.HD2017,      R.Tauren,   S.Male,   I.INVTYPE_BODY    )] = {  2.75,  0.00, -0.25, -0.25 },
    [Chr(O.HD2017,      R.Tauren,   S.Male,   I.INVTYPE_TABARD  )] = {  2.50,  0.00, -0.10, -0.25 },
    [Chr(O.HD2017,      R.Tauren,   S.Male,   I.INVTYPE_WRIST   )] = {  3.50, -0.40,  0.00, -0.50 },
    [Chr(O.HD2017,      R.Tauren,   S.Male,   I.INVTYPE_HAND    )] = {  3.15, -0.40,  0.10, -0.50 },
    [Chr(O.HD2017,      R.Tauren,   S.Male,   I.INVTYPE_WAIST   )] = {  3.50,  0.00,  0.00, -0.25 },
    [Chr(O.HD2017,      R.Tauren,   S.Male,   I.INVTYPE_LEGS    )] = {  3.15,  0.00,  0.40, -0.25 },
    [Chr(O.HD2017,      R.Tauren,   S.Male,   I.INVTYPE_FEET    )] = {  3.25,  0.00,  0.60, -0.50 },
    [Chr(O.HD2017,      R.Tauren,   S.Male,   I.SetsDetails     )] = {  1.00,  0.00, -0.33,  0.00 },
    [Chr(O.HD2017,      R.Tauren,   S.Male,   I.SetsVendor      )] = {  1.50,  0.00, -0.15,  0.00 },
    [Chr(O.HD2017,      R.Tauren,   S.Female, I.INVTYPE_HEAD    )] = {  2.20,  0.10, -0.35, -0.50 },
    [Chr(O.HD2017,      R.Tauren,   S.Female, I.INVTYPE_SHOULDER)] = {  2.25, -0.25, -0.30, -0.25 },
    [Chr(O.HD2017,      R.Tauren,   S.Female, I.INVTYPE_CLOAK   )] = {  1.15,  0.00,  0.25,  BACK },
    [Chr(O.HD2017,      R.Tauren,   S.Female, I.INVTYPE_CHEST   )] = {  2.00,  0.00, -0.05, -0.25 },
    [Chr(O.HD2017,      R.Tauren,   S.Female, I.INVTYPE_ROBE    )] = {  1.15,  0.00,  0.25, -0.25 },
    [Chr(O.HD2017,      R.Tauren,   S.Female, I.INVTYPE_BODY    )] = {  2.00,  0.00, -0.05, -0.25 },
    [Chr(O.HD2017,      R.Tauren,   S.Female, I.INVTYPE_TABARD  )] = {  1.45,  0.00,  0.15, -0.25 },
    [Chr(O.HD2017,      R.Tauren,   S.Female, I.INVTYPE_WRIST   )] = {  2.65, -0.32,  0.27, -0.50 },
    [Chr(O.HD2017,      R.Tauren,   S.Female, I.INVTYPE_HAND    )] = {  2.30, -0.30,  0.30, -0.50 },
    [Chr(O.HD2017,      R.Tauren,   S.Female, I.INVTYPE_WAIST   )] = {  2.35,  0.00,  0.30, -0.25 },
    [Chr(O.HD2017,      R.Tauren,   S.Female, I.INVTYPE_LEGS    )] = {  1.90,  0.00,  0.65, -0.25 },
    [Chr(O.HD2017,      R.Tauren,   S.Female, I.INVTYPE_FEET    )] = {  2.40,  0.00,  0.85, -0.35 },
    [Chr(O.HD2017,      R.Tauren,   S.Female, I.SetsDetails     )] = {  0.00,  0.00, -0.33,  0.00 },
    [Chr(O.HD2017,      R.Tauren,   S.Female, I.SetsVendor      )] = {  0.75,  0.00, -0.15,  0.00 },
    [Chr(O.HD2017,      R.Gnome,    S.Male,   I.INVTYPE_HEAD    )] = {  1.20,  0.00, -0.15, -0.50 },
    [Chr(O.HD2017,      R.Gnome,    S.Male,   I.INVTYPE_SHOULDER)] = {  1.45, -0.22, -0.10, -0.25 },
    [Chr(O.HD2017,      R.Gnome,    S.Male,   I.INVTYPE_CLOAK   )] = {  1.15,  0.00,  0.20,  BACK },
    [Chr(O.HD2017,      R.Gnome,    S.Male,   I.INVTYPE_CHEST   )] = {  1.25, -0.02,  0.05, -0.25 },
    [Chr(O.HD2017,      R.Gnome,    S.Male,   I.INVTYPE_ROBE    )] = {  1.15, -0.02,  0.15, -0.25 },
    [Chr(O.HD2017,      R.Gnome,    S.Male,   I.INVTYPE_BODY    )] = {  1.25, -0.02,  0.05, -0.25 },
    [Chr(O.HD2017,      R.Gnome,    S.Male,   I.INVTYPE_TABARD  )] = {  1.40,  0.00,  0.15, -0.25 },
    [Chr(O.HD2017,      R.Gnome,    S.Male,   I.INVTYPE_WRIST   )] = {  1.55, -0.25,  0.10, -0.50 },
    [Chr(O.HD2017,      R.Gnome,    S.Male,   I.INVTYPE_HAND    )] = {  1.55, -0.25,  0.15, -0.50 },
    [Chr(O.HD2017,      R.Gnome,    S.Male,   I.INVTYPE_WAIST   )] = {  1.45, -0.02,  0.15, -0.25 },
    [Chr(O.HD2017,      R.Gnome,    S.Male,   I.INVTYPE_LEGS    )] = {  1.40, -0.02,  0.30, -0.25 },
    [Chr(O.HD2017,      R.Gnome,    S.Male,   I.INVTYPE_FEET    )] = {  1.45, -0.02,  0.40, -1.00 },
    [Chr(O.HD2017,      R.Gnome,    S.Male,   I.SetsDetails     )] = {  0.50,  0.00, -0.10,  0.00 },
    [Chr(O.HD2017,      R.Gnome,    S.Male,   I.SetsVendor      )] = {  0.60,  0.00, -0.05,  0.00 },
    [Chr(O.HD2017,      R.Gnome,    S.Female, I.INVTYPE_HEAD    )] = {  1.00, -0.03, -0.20, -0.50 },
    [Chr(O.HD2017,      R.Gnome,    S.Female, I.INVTYPE_SHOULDER)] = {  1.20, -0.20, -0.05, -0.25 },
    [Chr(O.HD2017,      R.Gnome,    S.Female, I.INVTYPE_CLOAK   )] = {  1.00,  0.00,  0.18,  BACK },
    [Chr(O.HD2017,      R.Gnome,    S.Female, I.INVTYPE_CHEST   )] = {  1.20, -0.02,  0.10, -0.25 },
    [Chr(O.HD2017,      R.Gnome,    S.Female, I.INVTYPE_ROBE    )] = {  1.15, -0.02,  0.20, -0.25 },
    [Chr(O.HD2017,      R.Gnome,    S.Female, I.INVTYPE_BODY    )] = {  1.20, -0.02,  0.10, -0.25 },
    [Chr(O.HD2017,      R.Gnome,    S.Female, I.INVTYPE_TABARD  )] = {  1.25, -0.02,  0.16, -0.25 },
    [Chr(O.HD2017,      R.Gnome,    S.Female, I.INVTYPE_WRIST   )] = {  1.45, -0.20,  0.15, -0.50 },
    [Chr(O.HD2017,      R.Gnome,    S.Female, I.INVTYPE_HAND    )] = {  1.45, -0.21,  0.18, -0.50 },
    [Chr(O.HD2017,      R.Gnome,    S.Female, I.INVTYPE_WAIST   )] = {  1.35, -0.02,  0.20, -0.25 },
    [Chr(O.HD2017,      R.Gnome,    S.Female, I.INVTYPE_LEGS    )] = {  1.25, -0.02,  0.30, -0.25 },
    [Chr(O.HD2017,      R.Gnome,    S.Female, I.INVTYPE_FEET    )] = {  1.20, -0.06,  0.40, -1.00 },
    [Chr(O.HD2017,      R.Gnome,    S.Female, I.SetsDetails     )] = {  0.25,  0.00, -0.15,  0.00 },
    [Chr(O.HD2017,      R.Gnome,    S.Female, I.SetsVendor      )] = {  0.50,  0.00, -0.05,  0.00 },
    [Chr(O.HD2017,      R.Troll,    S.Male,   I.INVTYPE_HEAD    )] = {  3.15,  0.05, -1.00, -0.50 },
    [Chr(O.HD2017,      R.Troll,    S.Male,   I.INVTYPE_SHOULDER)] = {  2.95, -0.35, -0.95, -0.25 },
    [Chr(O.HD2017,      R.Troll,    S.Male,   I.INVTYPE_CLOAK   )] = {  2.00,  0.00, -0.25,  BACK },
    [Chr(O.HD2017,      R.Troll,    S.Male,   I.INVTYPE_CHEST   )] = {  2.60,  0.00, -0.70, -0.25 },
    [Chr(O.HD2017,      R.Troll,    S.Male,   I.INVTYPE_ROBE    )] = {  1.55,  0.00, -0.05, -0.25 },
    [Chr(O.HD2017,      R.Troll,    S.Male,   I.INVTYPE_BODY    )] = {  2.60,  0.00, -0.70, -0.25 },
    [Chr(O.HD2017,      R.Troll,    S.Male,   I.INVTYPE_TABARD  )] = {  2.35,  0.00, -0.30, -0.25 },
    [Chr(O.HD2017,      R.Troll,    S.Male,   I.INVTYPE_WRIST   )] = {  3.40, -0.75, -0.30, -0.20 },
    [Chr(O.HD2017,      R.Troll,    S.Male,   I.INVTYPE_HAND    )] = {  3.25, -0.75, -0.30,  0.05 },
    [Chr(O.HD2017,      R.Troll,    S.Male,   I.INVTYPE_WAIST   )] = {  3.40, -0.01, -0.25, -0.25 },
    [Chr(O.HD2017,      R.Troll,    S.Male,   I.INVTYPE_LEGS    )] = {  2.30,  0.00,  0.30, -0.25 },
    [Chr(O.HD2017,      R.Troll,    S.Male,   I.INVTYPE_FEET    )] = {  3.05, -0.05,  0.70, -0.80 },
    [Chr(O.HD2017,      R.Troll,    S.Male,   I.SetsDetails     )] = {  0.50, -0.02, -0.33,  0.00 },
    [Chr(O.HD2017,      R.Troll,    S.Male,   I.SetsVendor      )] = {  1.25, -0.02, -0.15,  0.00 },
    [Chr(O.HD2017,      R.Troll,    S.Female, I.INVTYPE_HEAD    )] = {  2.85,  0.00, -0.65, -0.50 },
    [Chr(O.HD2017,      R.Troll,    S.Female, I.INVTYPE_SHOULDER)] = {  2.85, -0.25, -0.45, -0.25 },
    [Chr(O.HD2017,      R.Troll,    S.Female, I.INVTYPE_CLOAK   )] = {  1.50, -0.10,  0.15,  BACK },
    [Chr(O.HD2017,      R.Troll,    S.Female, I.INVTYPE_CHEST   )] = {  2.85,  0.00, -0.30, -0.25 },
    [Chr(O.HD2017,      R.Troll,    S.Female, I.INVTYPE_ROBE    )] = {  1.40,  0.00,  0.20, -0.25 },
    [Chr(O.HD2017,      R.Troll,    S.Female, I.INVTYPE_BODY    )] = {  2.85,  0.00, -0.30, -0.25 },
    [Chr(O.HD2017,      R.Troll,    S.Female, I.INVTYPE_TABARD  )] = {  2.25,  0.00, -0.05, -0.25 },
    [Chr(O.HD2017,      R.Troll,    S.Female, I.INVTYPE_WRIST   )] = {  3.10, -0.25,  0.05, -0.50 },
    [Chr(O.HD2017,      R.Troll,    S.Female, I.INVTYPE_HAND    )] = {  2.90, -0.25,  0.10, -0.50 },
    [Chr(O.HD2017,      R.Troll,    S.Female, I.INVTYPE_WAIST   )] = {  3.00,  0.00,  0.00, -0.25 },
    [Chr(O.HD2017,      R.Troll,    S.Female, I.INVTYPE_LEGS    )] = {  1.90,  0.00,  0.45, -0.25 },
    [Chr(O.HD2017,      R.Troll,    S.Female, I.INVTYPE_FEET    )] = {  2.75,  0.00,  0.80, -0.50 },
    [Chr(O.HD2017,      R.Troll,    S.Female, I.SetsDetails     )] = {  0.00, -0.02, -0.33,  0.00 },
    [Chr(O.HD2017,      R.Troll,    S.Female, I.SetsVendor      )] = {  1.00, -0.02, -0.20,  0.00 },
    [Chr(O.HD2017,      R.BloodElf, S.Male,   I.INVTYPE_HEAD    )] = {  3.00, -0.10, -0.85, -0.50 },
    [Chr(O.HD2017,      R.BloodElf, S.Male,   I.INVTYPE_SHOULDER)] = {  2.80, -0.35, -0.70, -0.25 },
    [Chr(O.HD2017,      R.BloodElf, S.Male,   I.INVTYPE_CLOAK   )] = {  1.90, -0.06, -0.10,  BACK },
    [Chr(O.HD2017,      R.BloodElf, S.Male,   I.INVTYPE_CHEST   )] = {  2.45, -0.10, -0.55, -0.25 },
    [Chr(O.HD2017,      R.BloodElf, S.Male,   I.INVTYPE_ROBE    )] = {  1.75, -0.05,  0.00, -0.25 },
    [Chr(O.HD2017,      R.BloodElf, S.Male,   I.INVTYPE_BODY    )] = {  2.45, -0.10, -0.55, -0.25 },
    [Chr(O.HD2017,      R.BloodElf, S.Male,   I.INVTYPE_TABARD  )] = {  2.30, -0.07, -0.25, -0.25 },
    [Chr(O.HD2017,      R.BloodElf, S.Male,   I.INVTYPE_WRIST   )] = {  3.00, -0.45, -0.35, -0.50 },
    [Chr(O.HD2017,      R.BloodElf, S.Male,   I.INVTYPE_HAND    )] = {  2.80, -0.45, -0.30, -0.50 },
    [Chr(O.HD2017,      R.BloodElf, S.Male,   I.INVTYPE_WAIST   )] = {  2.95, -0.07, -0.30, -0.25 },
    [Chr(O.HD2017,      R.BloodElf, S.Male,   I.INVTYPE_LEGS    )] = {  2.15, -0.10,  0.20, -0.25 },
    [Chr(O.HD2017,      R.BloodElf, S.Male,   I.INVTYPE_FEET    )] = {  2.60, -0.10,  0.50, -1.00 },
    [Chr(O.HD2017,      R.BloodElf, S.Male,   I.SetsDetails     )] = {  0.50,  0.00, -0.33,  0.00 },
    [Chr(O.HD2017,      R.BloodElf, S.Male,   I.SetsVendor      )] = {  1.50,  0.00, -0.25,  0.00 },
    [Chr(O.HD2017,      R.BloodElf, S.Female, I.INVTYPE_HEAD    )] = {  2.30,  0.03, -0.65, -0.50 },
    [Chr(O.HD2017,      R.BloodElf, S.Female, I.INVTYPE_SHOULDER)] = {  2.45, -0.13, -0.55, -0.25 },
    [Chr(O.HD2017,      R.BloodElf, S.Female, I.INVTYPE_CLOAK   )] = {  1.30,  0.03,  0.00,  BACK },
    [Chr(O.HD2017,      R.BloodElf, S.Female, I.INVTYPE_CHEST   )] = {  2.30,  0.03, -0.35, -0.25 },
    [Chr(O.HD2017,      R.BloodElf, S.Female, I.INVTYPE_ROBE    )] = {  1.20,  0.02,  0.10, -0.25 },
    [Chr(O.HD2017,      R.BloodElf, S.Female, I.INVTYPE_BODY    )] = {  2.30,  0.03, -0.35, -0.25 },
    [Chr(O.HD2017,      R.BloodElf, S.Female, I.INVTYPE_TABARD  )] = {  1.95,  0.02, -0.17, -0.25 },
    [Chr(O.HD2017,      R.BloodElf, S.Female, I.INVTYPE_WRIST   )] = {  2.50, -0.15, -0.15, -0.50 },
    [Chr(O.HD2017,      R.BloodElf, S.Female, I.INVTYPE_HAND    )] = {  2.30, -0.15, -0.10, -0.50 },
    [Chr(O.HD2017,      R.BloodElf, S.Female, I.INVTYPE_WAIST   )] = {  2.40,  0.05, -0.20, -0.25 },
    [Chr(O.HD2017,      R.BloodElf, S.Female, I.INVTYPE_LEGS    )] = {  1.55,  0.00,  0.25, -0.25 },
    [Chr(O.HD2017,      R.BloodElf, S.Female, I.INVTYPE_FEET    )] = {  2.05,  0.00,  0.55, -0.90 },
    [Chr(O.HD2017,      R.BloodElf, S.Female, I.SetsDetails     )] = {  0.00,  0.03, -0.33,  0.00 },
    [Chr(O.HD2017,      R.BloodElf, S.Female, I.SetsVendor      )] = {  1.00,  0.03, -0.15,  0.00 },
    [Chr(O.HD2017,      R.Draenei,  S.Male,   I.INVTYPE_HEAD    )] = {  3.55,  0.05, -0.85, -0.50 },
    [Chr(O.HD2017,      R.Draenei,  S.Male,   I.INVTYPE_SHOULDER)] = {  3.20, -0.45, -0.70, -0.25 },
    [Chr(O.HD2017,      R.Draenei,  S.Male,   I.INVTYPE_CLOAK   )] = {  2.35,  0.00,  0.00,  BACK },
    [Chr(O.HD2017,      R.Draenei,  S.Male,   I.INVTYPE_CHEST   )] = {  2.90,  0.00, -0.45, -0.25 },
    [Chr(O.HD2017,      R.Draenei,  S.Male,   I.INVTYPE_ROBE    )] = {  2.10,  0.00,  0.15, -0.25 },
    [Chr(O.HD2017,      R.Draenei,  S.Male,   I.INVTYPE_BODY    )] = {  2.90,  0.00, -0.45, -0.25 },
    [Chr(O.HD2017,      R.Draenei,  S.Male,   I.INVTYPE_TABARD  )] = {  2.75,  0.00, -0.10, -0.25 },
    [Chr(O.HD2017,      R.Draenei,  S.Male,   I.INVTYPE_WRIST   )] = {  3.75, -0.35, -0.13, -0.50 },
    [Chr(O.HD2017,      R.Draenei,  S.Male,   I.INVTYPE_HAND    )] = {  3.45, -0.35, -0.05, -0.50 },
    [Chr(O.HD2017,      R.Draenei,  S.Male,   I.INVTYPE_WAIST   )] = {  3.45,  0.00, -0.10, -0.25 },
    [Chr(O.HD2017,      R.Draenei,  S.Male,   I.INVTYPE_LEGS    )] = {  2.90,  0.00,  0.45, -0.25 },
    [Chr(O.HD2017,      R.Draenei,  S.Male,   I.INVTYPE_FEET    )] = {  3.25,  0.00,  0.70, -0.80 },
    [Chr(O.HD2017,      R.Draenei,  S.Male,   I.SetsDetails     )] = {  0.50,  0.00, -0.33,  0.00 },
    [Chr(O.HD2017,      R.Draenei,  S.Male,   I.SetsVendor      )] = {  1.50,  0.00, -0.15,  0.00 },
    [Chr(O.HD2017,      R.Draenei,  S.Female, I.INVTYPE_HEAD    )] = {  2.75, -0.05, -0.85, -0.50 },
    [Chr(O.HD2017,      R.Draenei,  S.Female, I.INVTYPE_SHOULDER)] = {  3.05, -0.25, -0.75, -0.25 },
    [Chr(O.HD2017,      R.Draenei,  S.Female, I.INVTYPE_CLOAK   )] = {  1.90,  0.00, -0.05,  BACK },
    [Chr(O.HD2017,      R.Draenei,  S.Female, I.INVTYPE_CHEST   )] = {  2.80, -0.06, -0.50, -0.25 },
    [Chr(O.HD2017,      R.Draenei,  S.Female, I.INVTYPE_ROBE    )] = {  1.70, -0.02,  0.10, -0.25 },
    [Chr(O.HD2017,      R.Draenei,  S.Female, I.INVTYPE_BODY    )] = {  2.80, -0.06, -0.50, -0.25 },
    [Chr(O.HD2017,      R.Draenei,  S.Female, I.INVTYPE_TABARD  )] = {  2.40, -0.05, -0.23, -0.25 },
    [Chr(O.HD2017,      R.Draenei,  S.Female, I.INVTYPE_WRIST   )] = {  3.20, -0.27, -0.25, -0.50 },
    [Chr(O.HD2017,      R.Draenei,  S.Female, I.INVTYPE_HAND    )] = {  2.95, -0.27, -0.20, -0.50 },
    [Chr(O.HD2017,      R.Draenei,  S.Female, I.INVTYPE_WAIST   )] = {  3.00, -0.04, -0.25, -0.25 },
    [Chr(O.HD2017,      R.Draenei,  S.Female, I.INVTYPE_LEGS    )] = {  2.15, -0.02,  0.30, -0.25 },
    [Chr(O.HD2017,      R.Draenei,  S.Female, I.INVTYPE_FEET    )] = {  2.70, -0.05,  0.57, -0.80 },
    [Chr(O.HD2017,      R.Draenei,  S.Female, I.SetsDetails     )] = {  0.25,  0.00, -0.33,  0.00 },
    [Chr(O.HD2017,      R.Draenei,  S.Female, I.SetsVendor      )] = {  1.25,  0.00, -0.33,  0.00 },
    -- HD2019
    [Chr(O.HD2019,      R.Human,    S.Male,   I.INVTYPE_HEAD    )] = {  2.25,  0.05, -0.75, -0.50 },
    [Chr(O.HD2019,      R.Human,    S.Male,   I.INVTYPE_SHOULDER)] = {  2.00, -0.25, -0.65, -0.25 },
    [Chr(O.HD2019,      R.Human,    S.Male,   I.INVTYPE_CLOAK   )] = {  1.30,  0.02,  0.00,  BACK },
    [Chr(O.HD2019,      R.Human,    S.Male,   I.INVTYPE_CHEST   )] = {  1.90,  0.00, -0.45, -0.25 },
    [Chr(O.HD2019,      R.Human,    S.Male,   I.INVTYPE_ROBE    )] = {  1.10,  0.00,  0.05, -0.25 },
    [Chr(O.HD2019,      R.Human,    S.Male,   I.INVTYPE_BODY    )] = {  1.90,  0.00, -0.45, -0.25 },
    [Chr(O.HD2019,      R.Human,    S.Male,   I.INVTYPE_TABARD  )] = {  1.50,  0.00, -0.15, -0.25 },
    [Chr(O.HD2019,      R.Human,    S.Male,   I.INVTYPE_WRIST   )] = {  2.45, -0.25, -0.15, -0.50 },
    [Chr(O.HD2019,      R.Human,    S.Male,   I.INVTYPE_HAND    )] = {  2.20, -0.25, -0.10, -0.50 },
    [Chr(O.HD2019,      R.Human,    S.Male,   I.INVTYPE_WAIST   )] = {  2.20,  0.02, -0.20, -0.25 },
    [Chr(O.HD2019,      R.Human,    S.Male,   I.INVTYPE_LEGS    )] = {  1.60,  0.00,  0.25, -0.25 },
    [Chr(O.HD2019,      R.Human,    S.Male,   I.INVTYPE_FEET    )] = {  2.00,  0.05,  0.52, -0.80 },
    [Chr(O.HD2019,      R.Human,    S.Male,   I.SetsDetails     )] = {  0.00,  0.02, -0.33,  0.00 },
    [Chr(O.HD2019,      R.Human,    S.Male,   I.SetsVendor      )] = {  0.75,  0.02, -0.25,  0.00 },
    [Chr(O.HD2019,      R.Human,    S.Female, I.INVTYPE_HEAD    )] = {  1.90,  0.02, -0.67, -0.50 },
    [Chr(O.HD2019,      R.Human,    S.Female, I.INVTYPE_SHOULDER)] = {  1.95, -0.15, -0.60, -0.25 },
    [Chr(O.HD2019,      R.Human,    S.Female, I.INVTYPE_CLOAK   )] = {  1.10,  0.01, -0.10,  BACK },
    [Chr(O.HD2019,      R.Human,    S.Female, I.INVTYPE_CHEST   )] = {  1.80,  0.01, -0.40, -0.25 },
    [Chr(O.HD2019,      R.Human,    S.Female, I.INVTYPE_ROBE    )] = {  0.90,  0.01,  0.05, -0.25 },
    [Chr(O.HD2019,      R.Human,    S.Female, I.INVTYPE_BODY    )] = {  1.80,  0.01, -0.40, -0.25 },
    [Chr(O.HD2019,      R.Human,    S.Female, I.INVTYPE_TABARD  )] = {  1.40,  0.00, -0.15, -0.25 },
    [Chr(O.HD2019,      R.Human,    S.Female, I.INVTYPE_WRIST   )] = {  2.05, -0.16, -0.18, -0.50 },
    [Chr(O.HD2019,      R.Human,    S.Female, I.INVTYPE_HAND    )] = {  1.90, -0.16, -0.14, -0.50 },
    [Chr(O.HD2019,      R.Human,    S.Female, I.INVTYPE_WAIST   )] = {  1.90,  0.02, -0.20, -0.25 },
    [Chr(O.HD2019,      R.Human,    S.Female, I.INVTYPE_LEGS    )] = {  1.30,  0.00,  0.22, -0.25 },
    [Chr(O.HD2019,      R.Human,    S.Female, I.INVTYPE_FEET    )] = {  1.70,  0.03,  0.50, -0.35 },
    [Chr(O.HD2019,      R.Human,    S.Female, I.SetsDetails     )] = {  0.00,  0.02, -0.28,  0.00 },
    [Chr(O.HD2019,      R.Human,    S.Female, I.SetsVendor      )] = {  0.50,  0.02, -0.25,  0.00 },
    [Chr(O.HD2019,      R.Orc,      S.Male,   I.INVTYPE_HEAD    )] = {  2.30,  0.10, -0.85, -0.50 },
    [Chr(O.HD2019,      R.Orc,      S.Male,   I.INVTYPE_SHOULDER)] = {  1.90, -0.45, -0.80, -0.25 },
    [Chr(O.HD2019,      R.Orc,      S.Male,   I.INVTYPE_CLOAK   )] = {  1.05,  0.02, -0.05,  BACK },
    [Chr(O.HD2019,      R.Orc,      S.Male,   I.INVTYPE_CHEST   )] = {  1.65,  0.00, -0.50, -0.25 },
    [Chr(O.HD2019,      R.Orc,      S.Male,   I.INVTYPE_ROBE    )] = {  1.05,  0.00,  0.00, -0.25 },
    [Chr(O.HD2019,      R.Orc,      S.Male,   I.INVTYPE_BODY    )] = {  1.65,  0.00, -0.50, -0.25 },
    [Chr(O.HD2019,      R.Orc,      S.Male,   I.INVTYPE_TABARD  )] = {  1.70,  0.00, -0.20, -0.25 },
    [Chr(O.HD2019,      R.Orc,      S.Male,   I.INVTYPE_WRIST   )] = {  2.65, -0.40, -0.15, -0.50 },
    [Chr(O.HD2019,      R.Orc,      S.Male,   I.INVTYPE_HAND    )] = {  2.35, -0.40, -0.05, -0.50 },
    [Chr(O.HD2019,      R.Orc,      S.Male,   I.INVTYPE_WAIST   )] = {  2.35,  0.00, -0.25, -0.25 },
    [Chr(O.HD2019,      R.Orc,      S.Male,   I.INVTYPE_LEGS    )] = {  1.65,  0.00,  0.25, -0.25 },
    [Chr(O.HD2019,      R.Orc,      S.Male,   I.INVTYPE_FEET    )] = {  1.90,  0.00,  0.55, -1.00 },
    [Chr(O.HD2019,      R.Orc,      S.Male,   I.SetsDetails     )] = { -0.20,  0.02, -0.33,  0.00 },
    [Chr(O.HD2019,      R.Orc,      S.Male,   I.SetsVendor      )] = {  0.35,  0.02, -0.15,  0.00 },
    [Chr(O.HD2019,      R.Orc,      S.Female, I.INVTYPE_HEAD    )] = {  2.15,  0.02, -0.65, -0.50 },
    [Chr(O.HD2019,      R.Orc,      S.Female, I.INVTYPE_SHOULDER)] = {  2.00, -0.25, -0.55, -0.25 },
    [Chr(O.HD2019,      R.Orc,      S.Female, I.INVTYPE_CLOAK   )] = {  1.20,  0.00,  0.05,  BACK },
    [Chr(O.HD2019,      R.Orc,      S.Female, I.INVTYPE_CHEST   )] = {  2.05,  0.00, -0.30, -0.25 },
    [Chr(O.HD2019,      R.Orc,      S.Female, I.INVTYPE_ROBE    )] = {  1.10,  0.00,  0.15, -0.25 },
    [Chr(O.HD2019,      R.Orc,      S.Female, I.INVTYPE_BODY    )] = {  2.05,  0.00, -0.30, -0.25 },
    [Chr(O.HD2019,      R.Orc,      S.Female, I.INVTYPE_TABARD  )] = {  1.70,  0.00, -0.10, -0.25 },
    [Chr(O.HD2019,      R.Orc,      S.Female, I.INVTYPE_WRIST   )] = {  2.40, -0.25, -0.11, -0.50 },
    [Chr(O.HD2019,      R.Orc,      S.Female, I.INVTYPE_HAND    )] = {  2.20, -0.25, -0.04, -0.50 },
    [Chr(O.HD2019,      R.Orc,      S.Female, I.INVTYPE_WAIST   )] = {  2.30,  0.00, -0.15, -0.25 },
    [Chr(O.HD2019,      R.Orc,      S.Female, I.INVTYPE_LEGS    )] = {  1.45,  0.00,  0.35, -0.25 },
    [Chr(O.HD2019,      R.Orc,      S.Female, I.INVTYPE_FEET    )] = {  1.95,  0.00,  0.63, -1.00 },
    [Chr(O.HD2019,      R.Orc,      S.Female, I.SetsDetails     )] = {  0.00,  0.02, -0.28,  0.00 },
    [Chr(O.HD2019,      R.Orc,      S.Female, I.SetsVendor      )] = {  0.75,  0.02, -0.20,  0.00 },
    [Chr(O.HD2019,      R.Dwarf,    S.Male,   I.INVTYPE_HEAD    )] = {  2.45,  0.00, -0.60, -0.50 },
    [Chr(O.HD2019,      R.Dwarf,    S.Male,   I.INVTYPE_SHOULDER)] = {  2.35, -0.30, -0.55, -0.25 },
    [Chr(O.HD2019,      R.Dwarf,    S.Male,   I.INVTYPE_CLOAK   )] = {  1.80,  0.00, -0.10,  BACK },
    [Chr(O.HD2019,      R.Dwarf,    S.Male,   I.INVTYPE_CHEST   )] = {  1.95,  0.00, -0.30, -0.25 },
    [Chr(O.HD2019,      R.Dwarf,    S.Male,   I.INVTYPE_ROBE    )] = {  1.70,  0.00,  0.00, -0.25 },
    [Chr(O.HD2019,      R.Dwarf,    S.Male,   I.INVTYPE_BODY    )] = {  1.95,  0.00, -0.30, -0.25 },
    [Chr(O.HD2019,      R.Dwarf,    S.Male,   I.INVTYPE_TABARD  )] = {  2.15,  0.00, -0.15, -0.25 },
    [Chr(O.HD2019,      R.Dwarf,    S.Male,   I.INVTYPE_WRIST   )] = {  2.85, -0.30, -0.13, -0.50 },
    [Chr(O.HD2019,      R.Dwarf,    S.Male,   I.INVTYPE_HAND    )] = {  2.60, -0.32, -0.07, -0.50 },
    [Chr(O.HD2019,      R.Dwarf,    S.Male,   I.INVTYPE_WAIST   )] = {  2.50,  0.00, -0.10, -0.25 },
    [Chr(O.HD2019,      R.Dwarf,    S.Male,   I.INVTYPE_LEGS    )] = {  2.25, -0.01,  0.15, -0.25 },
    [Chr(O.HD2019,      R.Dwarf,    S.Male,   I.INVTYPE_FEET    )] = {  2.20, -0.05,  0.30, -0.85 },
    [Chr(O.HD2019,      R.Dwarf,    S.Male,   I.SetsDetails     )] = {  0.40,  0.00, -0.33,  0.00 },
    [Chr(O.HD2019,      R.Dwarf,    S.Male,   I.SetsVendor      )] = {  1.00,  0.00, -0.15,  0.00 },
    [Chr(O.HD2019,      R.Dwarf,    S.Male,   I.DressUp         )] = {  0.40,  0.00, -0.08,  0.00 },
    [Chr(O.HD2019,      R.Dwarf,    S.Female, I.INVTYPE_HEAD    )] = {  1.45, -0.02, -0.40, -0.50 },
    [Chr(O.HD2019,      R.Dwarf,    S.Female, I.INVTYPE_SHOULDER)] = {  1.55, -0.25, -0.25, -0.25 },
    [Chr(O.HD2019,      R.Dwarf,    S.Female, I.INVTYPE_CLOAK   )] = {  1.10, -0.05,  0.12,  BACK },
    [Chr(O.HD2019,      R.Dwarf,    S.Female, I.INVTYPE_CHEST   )] = {  1.40, -0.04, -0.05, -0.25 },
    [Chr(O.HD2019,      R.Dwarf,    S.Female, I.INVTYPE_ROBE    )] = {  1.00, -0.05,  0.20, -0.25 },
    [Chr(O.HD2019,      R.Dwarf,    S.Female, I.INVTYPE_BODY    )] = {  1.40, -0.04, -0.05, -0.25 },
    [Chr(O.HD2019,      R.Dwarf,    S.Female, I.INVTYPE_TABARD  )] = {  1.30, -0.02,  0.10, -0.25 },
    [Chr(O.HD2019,      R.Dwarf,    S.Female, I.INVTYPE_WRIST   )] = {  1.75, -0.25,  0.10, -0.50 },
    [Chr(O.HD2019,      R.Dwarf,    S.Female, I.INVTYPE_HAND    )] = {  1.65, -0.25,  0.13, -0.50 },
    [Chr(O.HD2019,      R.Dwarf,    S.Female, I.INVTYPE_WAIST   )] = {  1.55, -0.02,  0.07, -0.25 },
    [Chr(O.HD2019,      R.Dwarf,    S.Female, I.INVTYPE_LEGS    )] = {  1.30, -0.02,  0.35, -0.25 },
    [Chr(O.HD2019,      R.Dwarf,    S.Female, I.INVTYPE_FEET    )] = {  1.50, -0.02,  0.57, -0.85 },
    [Chr(O.HD2019,      R.Dwarf,    S.Female, I.SetsDetails     )] = {  0.20, -0.03, -0.15,  0.00 },
    [Chr(O.HD2019,      R.Dwarf,    S.Female, I.SetsVendor      )] = {  0.45, -0.03, -0.05,  0.00 },
    [Chr(O.HD2019,      R.Dwarf,    S.Female, I.DressUp         )] = {  0.05,  0.00,  0.05,  0.00 },
    [Chr(O.HD2019,      R.NightElf, S.Male,   I.INVTYPE_HEAD    )] = {  3.15,  0.00, -0.90, -0.50 },
    [Chr(O.HD2019,      R.NightElf, S.Male,   I.INVTYPE_SHOULDER)] = {  2.95, -0.30, -0.80, -0.25 },
    [Chr(O.HD2019,      R.NightElf, S.Male,   I.INVTYPE_CLOAK   )] = {  1.85,  0.00,  0.00,  BACK },
    [Chr(O.HD2019,      R.NightElf, S.Male,   I.INVTYPE_CHEST   )] = {  2.85, -0.05, -0.50, -0.25 },
    [Chr(O.HD2019,      R.NightElf, S.Male,   I.INVTYPE_ROBE    )] = {  1.65, -0.05,  0.05, -0.25 },
    [Chr(O.HD2019,      R.NightElf, S.Male,   I.INVTYPE_BODY    )] = {  2.85, -0.05, -0.50, -0.25 },
    [Chr(O.HD2019,      R.NightElf, S.Male,   I.INVTYPE_TABARD  )] = {  2.40,  0.00, -0.20, -0.25 },
    [Chr(O.HD2019,      R.NightElf, S.Male,   I.INVTYPE_WRIST   )] = {  3.45, -0.35, -0.23, -0.50 },
    [Chr(O.HD2019,      R.NightElf, S.Male,   I.INVTYPE_HAND    )] = {  3.10, -0.35, -0.13, -0.50 },
    [Chr(O.HD2019,      R.NightElf, S.Male,   I.INVTYPE_WAIST   )] = {  3.35, -0.01, -0.25, -0.25 },
    [Chr(O.HD2019,      R.NightElf, S.Male,   I.INVTYPE_LEGS    )] = {  2.30, -0.05,  0.30, -0.25 },
    [Chr(O.HD2019,      R.NightElf, S.Male,   I.INVTYPE_FEET    )] = {  2.85, -0.05,  0.64, -0.50 },
    [Chr(O.HD2019,      R.NightElf, S.Male,   I.SetsDetails     )] = {  0.05,  0.00, -0.33,  0.00 },
    [Chr(O.HD2019,      R.NightElf, S.Male,   I.SetsVendor      )] = {  1.15,  0.00, -0.25,  0.00 },
    [Chr(O.HD2019,      R.NightElf, S.Female, I.INVTYPE_HEAD    )] = {  3.05, -0.02, -0.80, -0.50 },
    [Chr(O.HD2019,      R.NightElf, S.Female, I.INVTYPE_SHOULDER)] = {  3.00, -0.23, -0.65, -0.25 },
    [Chr(O.HD2019,      R.NightElf, S.Female, I.INVTYPE_CLOAK   )] = {  1.70,  0.00,  0.00,  BACK },
    [Chr(O.HD2019,      R.NightElf, S.Female, I.INVTYPE_CHEST   )] = {  3.00, -0.02, -0.45, -0.25 },
    [Chr(O.HD2019,      R.NightElf, S.Female, I.INVTYPE_ROBE    )] = {  1.50, -0.01,  0.10, -0.25 },
    [Chr(O.HD2019,      R.NightElf, S.Female, I.INVTYPE_BODY    )] = {  3.00, -0.02, -0.45, -0.25 },
    [Chr(O.HD2019,      R.NightElf, S.Female, I.INVTYPE_TABARD  )] = {  2.50,  0.00, -0.20, -0.25 },
    [Chr(O.HD2019,      R.NightElf, S.Female, I.INVTYPE_WRIST   )] = {  3.40, -0.23, -0.20, -0.50 },
    [Chr(O.HD2019,      R.NightElf, S.Female, I.INVTYPE_HAND    )] = {  3.15, -0.23, -0.15, -0.50 },
    [Chr(O.HD2019,      R.NightElf, S.Female, I.INVTYPE_WAIST   )] = {  3.20,  0.00, -0.25, -0.25 },
    [Chr(O.HD2019,      R.NightElf, S.Female, I.INVTYPE_LEGS    )] = {  2.05,  0.00,  0.30, -0.25 },
    [Chr(O.HD2019,      R.NightElf, S.Female, I.INVTYPE_FEET    )] = {  2.70, -0.03,  0.66, -0.90 },
    [Chr(O.HD2019,      R.NightElf, S.Female, I.SetsDetails     )] = { -0.10,  0.00, -0.33,  0.00 },
    [Chr(O.HD2019,      R.NightElf, S.Female, I.SetsVendor      )] = {  1.10,  0.00, -0.25,  0.00 },
    [Chr(O.HD2019,      R.Scourge,  S.Male,   I.INVTYPE_HEAD    )] = {  2.10, -0.05, -0.85, -0.50 },
    [Chr(O.HD2019,      R.Scourge,  S.Male,   I.INVTYPE_SHOULDER)] = {  2.20, -0.35, -0.85, -0.05 },
    [Chr(O.HD2019,      R.Scourge,  S.Male,   I.INVTYPE_CLOAK   )] = {  1.00, -0.06, -0.15,  BACK },
    [Chr(O.HD2019,      R.Scourge,  S.Male,   I.INVTYPE_CHEST   )] = {  1.75, -0.10, -0.60, -0.25 },
    [Chr(O.HD2019,      R.Scourge,  S.Male,   I.INVTYPE_ROBE    )] = {  0.80, -0.10, -0.05, -0.25 },
    [Chr(O.HD2019,      R.Scourge,  S.Male,   I.INVTYPE_BODY    )] = {  1.75, -0.10, -0.60, -0.25 },
    [Chr(O.HD2019,      R.Scourge,  S.Male,   I.INVTYPE_TABARD  )] = {  1.50, -0.08, -0.30, -0.25 },
    [Chr(O.HD2019,      R.Scourge,  S.Male,   I.INVTYPE_WRIST   )] = {  2.35, -0.30, -0.30, -0.50 },
    [Chr(O.HD2019,      R.Scourge,  S.Male,   I.INVTYPE_HAND    )] = {  2.05, -0.30, -0.25, -0.50 },
    [Chr(O.HD2019,      R.Scourge,  S.Male,   I.INVTYPE_WAIST   )] = {  2.30, -0.10, -0.35, -0.25 },
    [Chr(O.HD2019,      R.Scourge,  S.Male,   I.INVTYPE_LEGS    )] = {  1.40, -0.10,  0.20, -0.25 },
    [Chr(O.HD2019,      R.Scourge,  S.Male,   I.INVTYPE_FEET    )] = {  2.00, -0.10,  0.50, -1.00 },
    [Chr(O.HD2019,      R.Scourge,  S.Male,   I.SetsDetails     )] = { -0.05,  0.00, -0.33,  0.00 },
    [Chr(O.HD2019,      R.Scourge,  S.Male,   I.SetsVendor      )] = {  0.75,  0.00, -0.20,  0.00 },
    [Chr(O.HD2019,      R.Scourge,  S.Female, I.INVTYPE_HEAD    )] = {  2.95,  0.00, -0.65, -0.50 },
    [Chr(O.HD2019,      R.Scourge,  S.Female, I.INVTYPE_SHOULDER)] = {  2.95, -0.20, -0.55, -0.25 },
    [Chr(O.HD2019,      R.Scourge,  S.Female, I.INVTYPE_CLOAK   )] = {  1.75,  0.00,  0.05,  BACK },
    [Chr(O.HD2019,      R.Scourge,  S.Female, I.INVTYPE_CHEST   )] = {  2.85, -0.02, -0.35, -0.25 },
    [Chr(O.HD2019,      R.Scourge,  S.Female, I.INVTYPE_ROBE    )] = {  1.55,  0.00,  0.10, -0.25 },
    [Chr(O.HD2019,      R.Scourge,  S.Female, I.INVTYPE_BODY    )] = {  2.85, -0.02, -0.35, -0.25 },
    [Chr(O.HD2019,      R.Scourge,  S.Female, I.INVTYPE_TABARD  )] = {  2.45,  0.00, -0.15, -0.25 },
    [Chr(O.HD2019,      R.Scourge,  S.Female, I.INVTYPE_WRIST   )] = {  3.20, -0.18, -0.15, -0.50 },
    [Chr(O.HD2019,      R.Scourge,  S.Female, I.INVTYPE_HAND    )] = {  2.95, -0.18, -0.10, -0.50 },
    [Chr(O.HD2019,      R.Scourge,  S.Female, I.INVTYPE_WAIST   )] = {  3.10,  0.00, -0.15, -0.25 },
    [Chr(O.HD2019,      R.Scourge,  S.Female, I.INVTYPE_LEGS    )] = {  2.20,  0.00,  0.29, -0.25 },
    [Chr(O.HD2019,      R.Scourge,  S.Female, I.INVTYPE_FEET    )] = {  2.70,  0.02,  0.55, -0.50 },
    [Chr(O.HD2019,      R.Scourge,  S.Female, I.SetsDetails     )] = {  0.33,  0.00, -0.25,  0.00 },
    [Chr(O.HD2019,      R.Scourge,  S.Female, I.SetsVendor      )] = {  1.25,  0.00, -0.15,  0.00 },
    [Chr(O.HD2019,      R.Tauren,   S.Male,   I.INVTYPE_HEAD    )] = {  3.00,  0.25, -0.50, -0.50 },
    [Chr(O.HD2019,      R.Tauren,   S.Male,   I.INVTYPE_SHOULDER)] = {  2.60, -0.45, -0.55, -0.25 },
    [Chr(O.HD2019,      R.Tauren,   S.Male,   I.INVTYPE_CLOAK   )] = {  2.05, -0.02,  0.00,  BACK },
    [Chr(O.HD2019,      R.Tauren,   S.Male,   I.INVTYPE_CHEST   )] = {  2.60,  0.00, -0.25, -0.25 },
    [Chr(O.HD2019,      R.Tauren,   S.Male,   I.INVTYPE_ROBE    )] = {  2.05,  0.00,  0.05, -0.25 },
    [Chr(O.HD2019,      R.Tauren,   S.Male,   I.INVTYPE_BODY    )] = {  2.60,  0.00, -0.25, -0.25 },
    [Chr(O.HD2019,      R.Tauren,   S.Male,   I.INVTYPE_TABARD  )] = {  2.30,  0.00, -0.10, -0.25 },
    [Chr(O.HD2019,      R.Tauren,   S.Male,   I.INVTYPE_WRIST   )] = {  3.45, -0.40,  0.00, -0.50 },
    [Chr(O.HD2019,      R.Tauren,   S.Male,   I.INVTYPE_HAND    )] = {  3.05, -0.40,  0.10, -0.50 },
    [Chr(O.HD2019,      R.Tauren,   S.Male,   I.INVTYPE_WAIST   )] = {  3.40,  0.00,  0.00, -0.25 },
    [Chr(O.HD2019,      R.Tauren,   S.Male,   I.INVTYPE_LEGS    )] = {  3.00,  0.00,  0.40, -0.25 },
    [Chr(O.HD2019,      R.Tauren,   S.Male,   I.INVTYPE_FEET    )] = {  3.15,  0.00,  0.60, -0.50 },
    [Chr(O.HD2019,      R.Tauren,   S.Male,   I.SetsDetails     )] = {  0.65,  0.00, -0.33,  0.00 },
    [Chr(O.HD2019,      R.Tauren,   S.Male,   I.SetsVendor      )] = {  1.20,  0.00, -0.15,  0.00 },
    [Chr(O.HD2019,      R.Tauren,   S.Female, I.INVTYPE_HEAD    )] = {  2.20,  0.10, -0.35, -0.50 },
    [Chr(O.HD2019,      R.Tauren,   S.Female, I.INVTYPE_SHOULDER)] = {  2.25, -0.25, -0.30, -0.25 },
    [Chr(O.HD2019,      R.Tauren,   S.Female, I.INVTYPE_CLOAK   )] = {  1.15,  0.00,  0.25,  BACK },
    [Chr(O.HD2019,      R.Tauren,   S.Female, I.INVTYPE_CHEST   )] = {  2.00,  0.00, -0.05, -0.25 },
    [Chr(O.HD2019,      R.Tauren,   S.Female, I.INVTYPE_ROBE    )] = {  1.15,  0.00,  0.25, -0.25 },
    [Chr(O.HD2019,      R.Tauren,   S.Female, I.INVTYPE_BODY    )] = {  2.00,  0.00, -0.05, -0.25 },
    [Chr(O.HD2019,      R.Tauren,   S.Female, I.INVTYPE_TABARD  )] = {  1.45,  0.00,  0.15, -0.25 },
    [Chr(O.HD2019,      R.Tauren,   S.Female, I.INVTYPE_WRIST   )] = {  2.65, -0.32,  0.27, -0.50 },
    [Chr(O.HD2019,      R.Tauren,   S.Female, I.INVTYPE_HAND    )] = {  2.30, -0.30,  0.30, -0.50 },
    [Chr(O.HD2019,      R.Tauren,   S.Female, I.INVTYPE_WAIST   )] = {  2.35,  0.00,  0.30, -0.25 },
    [Chr(O.HD2019,      R.Tauren,   S.Female, I.INVTYPE_LEGS    )] = {  1.90,  0.00,  0.65, -0.25 },
    [Chr(O.HD2019,      R.Tauren,   S.Female, I.INVTYPE_FEET    )] = {  2.40,  0.00,  0.85, -0.35 },
    [Chr(O.HD2019,      R.Tauren,   S.Female, I.SetsDetails     )] = {  0.00,  0.00, -0.33,  0.00 },
    [Chr(O.HD2019,      R.Tauren,   S.Female, I.SetsVendor      )] = {  0.75,  0.00, -0.15,  0.00 },
    [Chr(O.HD2019,      R.Gnome,    S.Male,   I.INVTYPE_HEAD    )] = {  1.00,  0.00, -0.15, -0.50 },
    [Chr(O.HD2019,      R.Gnome,    S.Male,   I.INVTYPE_SHOULDER)] = {  1.30, -0.22, -0.10, -0.25 },
    [Chr(O.HD2019,      R.Gnome,    S.Male,   I.INVTYPE_CLOAK   )] = {  0.95,  0.00,  0.20,  BACK },
    [Chr(O.HD2019,      R.Gnome,    S.Male,   I.INVTYPE_CHEST   )] = {  1.05, -0.02,  0.05, -0.25 },
    [Chr(O.HD2019,      R.Gnome,    S.Male,   I.INVTYPE_ROBE    )] = {  0.95, -0.02,  0.15, -0.25 },
    [Chr(O.HD2019,      R.Gnome,    S.Male,   I.INVTYPE_BODY    )] = {  1.05, -0.02,  0.05, -0.25 },
    [Chr(O.HD2019,      R.Gnome,    S.Male,   I.INVTYPE_TABARD  )] = {  1.25,  0.00,  0.15, -0.25 },
    [Chr(O.HD2019,      R.Gnome,    S.Male,   I.INVTYPE_WRIST   )] = {  1.45, -0.25,  0.10, -0.50 },
    [Chr(O.HD2019,      R.Gnome,    S.Male,   I.INVTYPE_HAND    )] = {  1.45, -0.25,  0.15, -0.50 },
    [Chr(O.HD2019,      R.Gnome,    S.Male,   I.INVTYPE_WAIST   )] = {  1.30, -0.02,  0.15, -0.25 },
    [Chr(O.HD2019,      R.Gnome,    S.Male,   I.INVTYPE_LEGS    )] = {  1.25, -0.02,  0.30, -0.25 },
    [Chr(O.HD2019,      R.Gnome,    S.Male,   I.INVTYPE_FEET    )] = {  1.35, -0.02,  0.40, -1.00 },
    [Chr(O.HD2019,      R.Gnome,    S.Male,   I.SetsDetails     )] = {  0.20,  0.00, -0.10,  0.00 },
    [Chr(O.HD2019,      R.Gnome,    S.Male,   I.SetsVendor      )] = {  0.25,  0.00, -0.10,  0.00 },
    [Chr(O.HD2019,      R.Gnome,    S.Female, I.INVTYPE_HEAD    )] = {  0.85, -0.03, -0.20, -0.50 },
    [Chr(O.HD2019,      R.Gnome,    S.Female, I.INVTYPE_SHOULDER)] = {  1.10, -0.20, -0.05, -0.25 },
    [Chr(O.HD2019,      R.Gnome,    S.Female, I.INVTYPE_CLOAK   )] = {  0.90,  0.00,  0.18,  BACK },
    [Chr(O.HD2019,      R.Gnome,    S.Female, I.INVTYPE_CHEST   )] = {  1.10, -0.02,  0.10, -0.25 },
    [Chr(O.HD2019,      R.Gnome,    S.Female, I.INVTYPE_ROBE    )] = {  1.05, -0.02,  0.20, -0.25 },
    [Chr(O.HD2019,      R.Gnome,    S.Female, I.INVTYPE_BODY    )] = {  1.10, -0.02,  0.10, -0.25 },
    [Chr(O.HD2019,      R.Gnome,    S.Female, I.INVTYPE_TABARD  )] = {  1.15, -0.02,  0.16, -0.25 },
    [Chr(O.HD2019,      R.Gnome,    S.Female, I.INVTYPE_WRIST   )] = {  1.45, -0.20,  0.15, -0.50 },
    [Chr(O.HD2019,      R.Gnome,    S.Female, I.INVTYPE_HAND    )] = {  1.40, -0.22,  0.18, -0.50 },
    [Chr(O.HD2019,      R.Gnome,    S.Female, I.INVTYPE_WAIST   )] = {  1.25, -0.02,  0.20, -0.25 },
    [Chr(O.HD2019,      R.Gnome,    S.Female, I.INVTYPE_LEGS    )] = {  1.15, -0.02,  0.30, -0.25 },
    [Chr(O.HD2019,      R.Gnome,    S.Female, I.INVTYPE_FEET    )] = {  1.10, -0.06,  0.40, -1.00 },
    [Chr(O.HD2019,      R.Gnome,    S.Female, I.SetsDetails     )] = {  0.00,  0.00, -0.15,  0.00 },
    [Chr(O.HD2019,      R.Gnome,    S.Female, I.SetsVendor      )] = {  0.30,  0.00, -0.05,  0.00 },
    [Chr(O.HD2019,      R.Troll,    S.Male,   I.INVTYPE_HEAD    )] = {  2.90,  0.05, -1.00, -0.50 },
    [Chr(O.HD2019,      R.Troll,    S.Male,   I.INVTYPE_SHOULDER)] = {  2.70, -0.35, -0.95, -0.25 },
    [Chr(O.HD2019,      R.Troll,    S.Male,   I.INVTYPE_CLOAK   )] = {  1.55,  0.00, -0.30,  BACK },
    [Chr(O.HD2019,      R.Troll,    S.Male,   I.INVTYPE_CHEST   )] = {  2.25,  0.00, -0.70, -0.25 },
    [Chr(O.HD2019,      R.Troll,    S.Male,   I.INVTYPE_ROBE    )] = {  0.95,  0.00, -0.10, -0.25 },
    [Chr(O.HD2019,      R.Troll,    S.Male,   I.INVTYPE_BODY    )] = {  2.25,  0.00, -0.70, -0.25 },
    [Chr(O.HD2019,      R.Troll,    S.Male,   I.INVTYPE_TABARD  )] = {  1.95,  0.00, -0.30, -0.25 },
    [Chr(O.HD2019,      R.Troll,    S.Male,   I.INVTYPE_WRIST   )] = {  3.25, -0.75, -0.30, -0.20 },
    [Chr(O.HD2019,      R.Troll,    S.Male,   I.INVTYPE_HAND    )] = {  3.05, -0.75, -0.30,  0.05 },
    [Chr(O.HD2019,      R.Troll,    S.Male,   I.INVTYPE_WAIST   )] = {  3.25, -0.01, -0.25, -0.25 },
    [Chr(O.HD2019,      R.Troll,    S.Male,   I.INVTYPE_LEGS    )] = {  1.85,  0.00,  0.30, -0.25 },
    [Chr(O.HD2019,      R.Troll,    S.Male,   I.INVTYPE_FEET    )] = {  2.80, -0.05,  0.70, -0.80 },
    [Chr(O.HD2019,      R.Troll,    S.Male,   I.SetsDetails     )] = { -0.20, -0.02, -0.33,  0.00 },
    [Chr(O.HD2019,      R.Troll,    S.Male,   I.SetsVendor      )] = {  0.65, -0.02, -0.15,  0.00 },
    [Chr(O.HD2019,      R.Troll,    S.Female, I.INVTYPE_HEAD    )] = {  2.85,  0.00, -0.65, -0.50 },
    [Chr(O.HD2019,      R.Troll,    S.Female, I.INVTYPE_SHOULDER)] = {  2.85, -0.25, -0.45, -0.25 },
    [Chr(O.HD2019,      R.Troll,    S.Female, I.INVTYPE_CLOAK   )] = {  1.50, -0.10,  0.15,  BACK },
    [Chr(O.HD2019,      R.Troll,    S.Female, I.INVTYPE_CHEST   )] = {  2.85,  0.00, -0.30, -0.25 },
    [Chr(O.HD2019,      R.Troll,    S.Female, I.INVTYPE_ROBE    )] = {  1.40,  0.00,  0.20, -0.25 },
    [Chr(O.HD2019,      R.Troll,    S.Female, I.INVTYPE_BODY    )] = {  2.85,  0.00, -0.30, -0.25 },
    [Chr(O.HD2019,      R.Troll,    S.Female, I.INVTYPE_TABARD  )] = {  2.25,  0.00, -0.05, -0.25 },
    [Chr(O.HD2019,      R.Troll,    S.Female, I.INVTYPE_WRIST   )] = {  3.10, -0.25,  0.05, -0.50 },
    [Chr(O.HD2019,      R.Troll,    S.Female, I.INVTYPE_HAND    )] = {  2.90, -0.25,  0.10, -0.50 },
    [Chr(O.HD2019,      R.Troll,    S.Female, I.INVTYPE_WAIST   )] = {  3.00,  0.00,  0.00, -0.25 },
    [Chr(O.HD2019,      R.Troll,    S.Female, I.INVTYPE_LEGS    )] = {  1.90,  0.00,  0.45, -0.25 },
    [Chr(O.HD2019,      R.Troll,    S.Female, I.INVTYPE_FEET    )] = {  2.75,  0.00,  0.80, -0.50 },
    [Chr(O.HD2019,      R.Troll,    S.Female, I.SetsDetails     )] = {  0.00, -0.02, -0.33,  0.00 },
    [Chr(O.HD2019,      R.Troll,    S.Female, I.SetsVendor      )] = {  1.00, -0.02, -0.20,  0.00 },
    [Chr(O.HD2019,      R.BloodElf, S.Male,   I.INVTYPE_HEAD    )] = {  2.90, -0.10, -0.85, -0.50 },
    [Chr(O.HD2019,      R.BloodElf, S.Male,   I.INVTYPE_SHOULDER)] = {  2.70, -0.35, -0.70, -0.25 },
    [Chr(O.HD2019,      R.BloodElf, S.Male,   I.INVTYPE_CLOAK   )] = {  1.70, -0.06, -0.10,  BACK },
    [Chr(O.HD2019,      R.BloodElf, S.Male,   I.INVTYPE_CHEST   )] = {  2.30, -0.10, -0.55, -0.25 },
    [Chr(O.HD2019,      R.BloodElf, S.Male,   I.INVTYPE_ROBE    )] = {  1.50, -0.05,  0.00, -0.25 },
    [Chr(O.HD2019,      R.BloodElf, S.Male,   I.INVTYPE_BODY    )] = {  2.30, -0.10, -0.55, -0.25 },
    [Chr(O.HD2019,      R.BloodElf, S.Male,   I.INVTYPE_TABARD  )] = {  2.15, -0.07, -0.25, -0.25 },
    [Chr(O.HD2019,      R.BloodElf, S.Male,   I.INVTYPE_WRIST   )] = {  2.95, -0.45, -0.35, -0.50 },
    [Chr(O.HD2019,      R.BloodElf, S.Male,   I.INVTYPE_HAND    )] = {  2.70, -0.45, -0.30, -0.50 },
    [Chr(O.HD2019,      R.BloodElf, S.Male,   I.INVTYPE_WAIST   )] = {  2.85, -0.07, -0.30, -0.25 },
    [Chr(O.HD2019,      R.BloodElf, S.Male,   I.INVTYPE_LEGS    )] = {  2.00, -0.10,  0.20, -0.25 },
    [Chr(O.HD2019,      R.BloodElf, S.Male,   I.INVTYPE_FEET    )] = {  2.45, -0.10,  0.50, -1.00 },
    [Chr(O.HD2019,      R.BloodElf, S.Male,   I.SetsDetails     )] = {  0.10,  0.00, -0.33,  0.00 },
    [Chr(O.HD2019,      R.BloodElf, S.Male,   I.SetsVendor      )] = {  1.20,  0.00, -0.25,  0.00 },
    [Chr(O.HD2019,      R.BloodElf, S.Female, I.INVTYPE_HEAD    )] = {  2.30,  0.03, -0.65, -0.50 },
    [Chr(O.HD2019,      R.BloodElf, S.Female, I.INVTYPE_SHOULDER)] = {  2.45, -0.13, -0.55, -0.25 },
    [Chr(O.HD2019,      R.BloodElf, S.Female, I.INVTYPE_CLOAK   )] = {  1.30,  0.03,  0.00,  BACK },
    [Chr(O.HD2019,      R.BloodElf, S.Female, I.INVTYPE_CHEST   )] = {  2.30,  0.03, -0.35, -0.25 },
    [Chr(O.HD2019,      R.BloodElf, S.Female, I.INVTYPE_ROBE    )] = {  1.20,  0.02,  0.10, -0.25 },
    [Chr(O.HD2019,      R.BloodElf, S.Female, I.INVTYPE_BODY    )] = {  2.30,  0.03, -0.35, -0.25 },
    [Chr(O.HD2019,      R.BloodElf, S.Female, I.INVTYPE_TABARD  )] = {  1.95,  0.02, -0.17, -0.25 },
    [Chr(O.HD2019,      R.BloodElf, S.Female, I.INVTYPE_WRIST   )] = {  2.50, -0.15, -0.15, -0.50 },
    [Chr(O.HD2019,      R.BloodElf, S.Female, I.INVTYPE_HAND    )] = {  2.30, -0.15, -0.10, -0.50 },
    [Chr(O.HD2019,      R.BloodElf, S.Female, I.INVTYPE_WAIST   )] = {  2.40,  0.05, -0.20, -0.25 },
    [Chr(O.HD2019,      R.BloodElf, S.Female, I.INVTYPE_LEGS    )] = {  1.55,  0.00,  0.25, -0.25 },
    [Chr(O.HD2019,      R.BloodElf, S.Female, I.INVTYPE_FEET    )] = {  2.05,  0.00,  0.55, -0.90 },
    [Chr(O.HD2019,      R.BloodElf, S.Female, I.SetsDetails     )] = {  0.00,  0.03, -0.33,  0.00 },
    [Chr(O.HD2019,      R.BloodElf, S.Female, I.SetsVendor      )] = {  0.95,  0.03, -0.15,  0.00 },
    [Chr(O.HD2019,      R.Draenei,  S.Male,   I.INVTYPE_HEAD    )] = {  3.30,  0.05, -0.85, -0.50 },
    [Chr(O.HD2019,      R.Draenei,  S.Male,   I.INVTYPE_SHOULDER)] = {  2.95, -0.45, -0.70, -0.25 },
    [Chr(O.HD2019,      R.Draenei,  S.Male,   I.INVTYPE_CLOAK   )] = {  1.85,  0.00,  0.00,  BACK },
    [Chr(O.HD2019,      R.Draenei,  S.Male,   I.INVTYPE_CHEST   )] = {  2.50,  0.00, -0.45, -0.25 },
    [Chr(O.HD2019,      R.Draenei,  S.Male,   I.INVTYPE_ROBE    )] = {  1.55,  0.00,  0.15, -0.25 },
    [Chr(O.HD2019,      R.Draenei,  S.Male,   I.INVTYPE_BODY    )] = {  2.50,  0.00, -0.45, -0.25 },
    [Chr(O.HD2019,      R.Draenei,  S.Male,   I.INVTYPE_TABARD  )] = {  2.35,  0.00, -0.10, -0.25 },
    [Chr(O.HD2019,      R.Draenei,  S.Male,   I.INVTYPE_WRIST   )] = {  3.65, -0.35, -0.13, -0.50 },
    [Chr(O.HD2019,      R.Draenei,  S.Male,   I.INVTYPE_HAND    )] = {  3.25, -0.35, -0.05, -0.50 },
    [Chr(O.HD2019,      R.Draenei,  S.Male,   I.INVTYPE_WAIST   )] = {  3.20,  0.00, -0.10, -0.25 },
    [Chr(O.HD2019,      R.Draenei,  S.Male,   I.INVTYPE_LEGS    )] = {  2.50,  0.00,  0.45, -0.25 },
    [Chr(O.HD2019,      R.Draenei,  S.Male,   I.INVTYPE_FEET    )] = {  2.95,  0.00,  0.70, -0.80 },
    [Chr(O.HD2019,      R.Draenei,  S.Male,   I.SetsDetails     )] = { -0.40,  0.00, -0.33,  0.00 },
    [Chr(O.HD2019,      R.Draenei,  S.Male,   I.SetsVendor      )] = {  0.75,  0.00, -0.15,  0.00 },
    [Chr(O.HD2019,      R.Draenei,  S.Female, I.INVTYPE_HEAD    )] = {  2.75, -0.05, -0.85, -0.50 },
    [Chr(O.HD2019,      R.Draenei,  S.Female, I.INVTYPE_SHOULDER)] = {  3.05, -0.25, -0.75, -0.25 },
    [Chr(O.HD2019,      R.Draenei,  S.Female, I.INVTYPE_CLOAK   )] = {  1.90,  0.00, -0.05,  BACK },
    [Chr(O.HD2019,      R.Draenei,  S.Female, I.INVTYPE_CHEST   )] = {  2.80, -0.06, -0.50, -0.25 },
    [Chr(O.HD2019,      R.Draenei,  S.Female, I.INVTYPE_ROBE    )] = {  1.70, -0.02,  0.10, -0.25 },
    [Chr(O.HD2019,      R.Draenei,  S.Female, I.INVTYPE_BODY    )] = {  2.80, -0.06, -0.50, -0.25 },
    [Chr(O.HD2019,      R.Draenei,  S.Female, I.INVTYPE_TABARD  )] = {  2.40, -0.05, -0.23, -0.25 },
    [Chr(O.HD2019,      R.Draenei,  S.Female, I.INVTYPE_WRIST   )] = {  3.20, -0.27, -0.25, -0.50 },
    [Chr(O.HD2019,      R.Draenei,  S.Female, I.INVTYPE_HAND    )] = {  2.95, -0.27, -0.20, -0.50 },
    [Chr(O.HD2019,      R.Draenei,  S.Female, I.INVTYPE_WAIST   )] = {  3.00, -0.04, -0.25, -0.25 },
    [Chr(O.HD2019,      R.Draenei,  S.Female, I.INVTYPE_LEGS    )] = {  2.15, -0.02,  0.30, -0.25 },
    [Chr(O.HD2019,      R.Draenei,  S.Female, I.INVTYPE_FEET    )] = {  2.70, -0.05,  0.57, -0.80 },
    [Chr(O.HD2019,      R.Draenei,  S.Female, I.SetsDetails     )] = {  0.16,  0.00, -0.33,  0.00 },
    [Chr(O.HD2019,      R.Draenei,  S.Female, I.SetsVendor      )] = {  1.20,  0.00, -0.33,  0.00 },
};
